@@ -1,6 +1,6 @@
 /****************************************************************************
 *  Copyright (C) 1996-98 by Leo Khramov
-*  email:     leo@unix1.jinr.dubna.su
+*  email:     leo@xnc.dubna.su
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -19,30 +19,33 @@
 #include "panel.h"
 #include "query_windows.h"
 #include "infowin.h"
+#include "c_externs.h"
+#include "bookmark.h"
 
 #define AFS_CACHE_MEM        50000
 
-extern "C" int psystem(char *);
+int    dont_update = 0;                //don't ask for update archives on exiting from it. (Never do it);
 
 // The return value is static, so copy it before using the
 // method again!
 
 char *create_dirs(char *rootdir, char* dirlist)
 {
-   char str[PATH_MAX];
+   char str[L_MAXPATH];
    char cont[FLIST_NAME];
    strcpy(str,rootdir);
    do{
            dirlist=get_first_content(dirlist,cont);
            add_path_content(str,cont);
            if(::mkdir(str,0755)==-1 && errno !=EEXIST)
-                   return;
+                   return NULL;
        } while(dirlist);
+   return rootdir;
 }
 
 char  *AFS::get_dir_header()
 {
-  static char strtmp[2*PATH_MAX];
+  static char strtmp[2*L_MAXPATH];
    
   sprintf(strtmp, "%s[%s]:%s", sp->name, arcname, curdir);
   return strtmp;
@@ -50,21 +53,21 @@ char  *AFS::get_dir_header()
 
 int    AFS::can_we_optimize()
 {
-  if (sp->luarc[0] == -1 && sp->luarc[1] == -1)
+  if (sp->luarc[0] == (char)-1 && sp->luarc[1] == (char)-1)
     return 0;
   return 1;
 }
 
 int    AFS::is_pocket_addition_allowed()
 {
-  if (sp->lparc[0] == -1 && sp->lparc[1] == -1)
+  if (sp->lparc[0] == (char)-1 && sp->lparc[1] == (char)-1)
     return 0;
   return 1;
 }
 
 int    AFS::is_full_extract_allowed()
 {
-  if (sp->uarc[0] == -1 && sp->uarc[1] == -1)
+  if (sp->uarc[0] == (char)-1 && sp->uarc[1] == (char)-1)
     return 0;
   if (sublevel == 0)
     return 1;
@@ -73,21 +76,21 @@ int    AFS::is_full_extract_allowed()
 
 int    AFS::is_exec_supported()
 {
-  if (sp->sarc[0] == -1 && sp->sarc[1] == -1)
+  if (sp->sarc[0] == (char)-1 && sp->sarc[1] == (char)-1)
     return 0;
   return 1;
 }
 
 int    AFS::is_copy_supported()
 {
-  if (sp->sarc[0] == -1 && sp->sarc[1] == -1)
+  if (sp->sarc[0] == (char)-1 && sp->sarc[1] == (char)-1)
     return 0;
   return 1;
 }
 
 int    AFS::is_del_supported()
 {
-  if (sp->darc[0] == -1 && sp->darc[1] == -1)
+  if (sp->darc[0] == (char)-1 && sp->darc[1] == (char)-1)
     return 0;
   return 1;
 }
@@ -119,7 +122,7 @@ void   AFS::delete_vfs_list()
   char  *b;
   char  strtmp[4096];
 
-  if (update_on_exit && dont_update != 2 && (sp->pdarc[0] != -1 || sp->pdarc[1] != -1))
+  if (update_on_exit && dont_update != 2 && (sp->pdarc[0] != (char)-1 || sp->pdarc[1] != (char)-1))
     {
       if (dont_update == 0)
         ask_for_update();
@@ -174,7 +177,7 @@ int    AFS::remove(FList * cur)
     sprintf(strtmp, "%s/%s", curdir + 2, cur->name);
   if (cur->mode & S_IFDIR)
     strcat(strtmp, "/*");
-  sp->quote_path(strtmp2, strtmp);
+  quote_path(strtmp2, strtmp);
   sp->single_delete_command(strtmp, fullarcname, strtmp2);
   r = psystem(strtmp);                //Add error checking here!!!!!!!!!!!!
 
@@ -196,9 +199,9 @@ char  *AFS::get_file_for_execute(char *vfsname)
 {
   char  *b;
   int    r;
-  char   strtmp[2*PATH_MAX];
-  char   strtmp2[2*PATH_MAX];
-  char   strtmp3[2*PATH_MAX];
+  char   strtmp[2*L_MAXPATH];
+  char   strtmp2[2*L_MAXPATH];
+  char   strtmp3[2*L_MAXPATH];
   static char   filename[FLIST_NAME];
   struct stat dstat;
   FList *o;
@@ -249,7 +252,7 @@ char  *AFS::get_file_for_execute(char *vfsname)
   else
     sprintf(strtmp, "%s/%s", curdir + 2, filename);
     
-  sp->quote_path(strtmp2, strtmp);
+  quote_path(strtmp2, strtmp);
   sp->single_extract_command(strtmp, fullarcname, strtmp2);
 // *INDENT-OFF*        
   if (::chdir(tmppath) == -1)
@@ -289,7 +292,7 @@ int    AFS::full_extract_to_vfs(VFS * vfs)
   int    r;
   char  *b;
   FList *o = dl.next;
-  char  strtmp[2*PATH_MAX];
+  char  strtmp[2*L_MAXPATH];
   
   if (vfs->fstype != DFS_TYPE)
     {
@@ -301,7 +304,7 @@ int    AFS::full_extract_to_vfs(VFS * vfs)
     while (o != NULL)                //First of all check file existance
 
       {
-        if (o->mode & S_SELECT)
+        if (o->options & S_SELECT)
           {
             if (vfs->is_file_exist(vfs->curdir, o->name))
               {
@@ -312,7 +315,7 @@ int    AFS::full_extract_to_vfs(VFS * vfs)
                     return ow_cancel;        //if cancel we return as error!!!
 
                   else
-                    o->mode ^= S_SELECT;
+                    o->options &= ~S_SELECT;
               }
           }
         ow_file = 0;
@@ -358,14 +361,14 @@ int    AFS::optimized_copy_to_dfs(VFS * vfs)
   int    r = 0;
   FILE  *fp;
   char  *b;
-  char  strtmp[2*PATH_MAX];
-  char  strtmp2[2*PATH_MAX];
+  char  strtmp[2*L_MAXPATH];
+  char  strtmp2[2*L_MAXPATH];
   
   if (dont_ask == 0)
     while (o != NULL)                //First of all check file existance
 
       {
-        if (o->mode & S_SELECT)
+        if (o->options & S_SELECT)
           {
             if (vfs->is_file_exist(vfs->curdir, o->name))
               {
@@ -376,7 +379,7 @@ int    AFS::optimized_copy_to_dfs(VFS * vfs)
                     return ow_cancel;        //if cancel we return as error!!!
 
                   else
-                    o->mode ^= S_SELECT;
+                    o->options &= ~S_SELECT;
               }
           }
         ow_file = 0;
@@ -399,7 +402,7 @@ int    AFS::optimized_copy_to_dfs(VFS * vfs)
     need_tmp = 1;
   while (o != NULL)
     {
-      if (o->mode & S_SELECT)
+      if (o->options & S_SELECT)
         {
           if (need_tmp == 0)
             {
@@ -455,12 +458,12 @@ int    AFS::optimized_copy_to_dfs(VFS * vfs)
       o = dl.next;
       while (o != NULL)
         {
-          if (o->mode & S_SELECT)
+          if (o->options & S_SELECT)
             {
               if (df.move(o, vfs))
                 r |= 1;
               else
-                o->mode ^= S_SELECT;
+                o->options &= ~S_SELECT;
             }
           o = o->next;
         }
@@ -470,8 +473,7 @@ int    AFS::optimized_copy_to_dfs(VFS * vfs)
       o = dl.next;
       while (o != NULL)
         {
-          if (o->mode & S_SELECT)
-            o->mode ^= S_SELECT;
+          o->options &= ~S_SELECT;
           o = o->next;
         }
     }
@@ -487,11 +489,11 @@ int    AFS::optimized_copy_to_dfs(VFS * vfs)
 int    AFS::add_to_vfs_by_list(FList * dd)
 {
   FList *o = dd;
-  char   s[PATH_MAX];
+  char   s[L_MAXPATH];
   int    r = 0;
   FILE  *fp;
-  char   strtmp[2*PATH_MAX];
-  char   strtmp2[2*PATH_MAX];
+  char   strtmp[2*L_MAXPATH];
+  char   strtmp2[2*L_MAXPATH];
 
   sprintf(s, "%s/AFS/.list", syspath);
   fp = fopen(s, "w");
@@ -502,7 +504,7 @@ int    AFS::add_to_vfs_by_list(FList * dd)
     };
   while (o != NULL)
     {
-      if (o->mode & S_SELECT)
+      if (o->options & S_SELECT)
         {
           sprintf(strtmp2, "%s", o->name);
           if (o->mode & S_IFDIR)
@@ -521,8 +523,7 @@ int    AFS::add_to_vfs_by_list(FList * dd)
       o = dd;
       while (o != NULL)
         {
-          if (o->mode & S_SELECT)
-            o->mode ^= S_SELECT;
+          o->options &= ~S_SELECT;
           o = o->next;
         }
     }
@@ -535,8 +536,14 @@ int    AFS::copy(FList * cur, VFS * vfs)
   int    r;
   int    need_tmp = 1;
   char  *b;
-  char   strtmp[2*PATH_MAX];
-  char   strtmp2[2*PATH_MAX];
+  char   strtmp[2*L_MAXPATH];
+  char   strtmp2[2*L_MAXPATH];
+  
+  if(sp->sarc[0]==(char)-1 && sp->sarc[1]==(char)-1)
+  {
+          vfs_error(sp->name,"Operation not supported in this archive");
+          return 255;
+  }
   
   if (vfs->is_copy_supported())
     {
@@ -587,7 +594,7 @@ int    AFS::copy(FList * cur, VFS * vfs)
             sprintf(strtmp, "%s/%s", curdir + 2, cur->name);
           if (cur->mode & S_IFDIR)
             strcat(strtmp, "/*");
-          sp->quote_path(strtmp2, strtmp);
+          quote_path(strtmp2, strtmp);
           sp->single_extract_command(strtmp, fullarcname, strtmp2);
 // *INDENT-OFF*        
           if (need_tmp == 0)
@@ -629,7 +636,7 @@ int    AFS::copy(FList * cur, VFS * vfs)
 
 char  *AFS::get_execute_dir()
 {
-  static char strtmp[PATH_MAX];
+  static char strtmp[L_MAXPATH];
    
   if (strcmp(curdir, ".") == 0)
     return tmppath;
@@ -684,7 +691,7 @@ int    AFS::init_support(char *fname)
   return reread();
 }
 
-void   AFS::convert_attributes(int &mode, int siz, char *at)
+void   AFS::convert_attributes(int &mode, int siz, char *at, char *name)
 {
   mode = 0;
   int    i, delta = 1;
@@ -702,7 +709,7 @@ void   AFS::convert_attributes(int &mode, int siz, char *at)
             mode |= S_IFDIR;
           else if (at[0] == '.' && siz == 0)
             mode |= S_IFDIR;
-          if(at[0] == 'l')
+          if(at[0] == 'l' || check_for_link(name))
                   mode |= S_IFLNK;
         }
       else
@@ -783,9 +790,9 @@ int    AFS::chdir(char *d)
 
 char  *AFS::gen_fullname(char *n)
 {
-  static char strtmp[PATH_MAX];
-   
-  int    i = 2;
+  static char strtmp[L_MAXPATH];
+  int    i ;
+  i=2;
   if (*n == '/')
     n++;
   if (n[0] == '.' && n[1] == '/')
@@ -799,6 +806,8 @@ char  *AFS::gen_fullname(char *n)
     strtmp[i++] = *n++;
   if (strtmp[i - 1] == '/')
     i--;
+  strtmp[i++] = 0;
+  strtmp[i++] = 0;
   strtmp[i] = 0;
   return strtmp;
 }
@@ -806,22 +815,22 @@ char  *AFS::gen_fullname(char *n)
 int    AFS::add_to_vfs(FList * cur)
 {
   int    r;
-  char   strtmp[2*PATH_MAX];
-  char   strtmp2[2*PATH_MAX];
+  char   strtmp[2*L_MAXPATH];
+  char   strtmp2[2*L_MAXPATH];
 
   if (cur->mode & S_IFDIR)
     {
-      if (sp->parc[0] == -1 && sp->parc[1] == -1)
+      if (sp->parc[0] == (char)-1 && sp->parc[1] == (char)-1)
         return 255;
       else
         sp->single_pack_dir_command(strtmp, fullarcname,
-                                    sp->quote_path(strtmp2, cur->name));
+                                    quote_path(strtmp2, cur->name));
     }
-  else if (sp->parc[0] == -1 && sp->parc[1] == -1)
+  else if (sp->parc[0] == (char)-1 && sp->parc[1] == (char)-1)
     return 255;
   else
     sp->single_pack_file_command(strtmp, fullarcname,
-                                 sp->quote_path(strtmp2, cur->name));
+                                 quote_path(strtmp2, cur->name));
   r = psystem(strtmp);
   if (r == 0)
     need_reread = 1;
@@ -902,7 +911,7 @@ void *AFS::cache_alloc(int size)
 void*   AFS::find_in_cache(char *name)
 {
   char  *b, *s;
-  int    sl = 0,l;
+  int    sl = 0;
   DTree *obj=&dtree_obj, *o;
   
 
@@ -949,6 +958,8 @@ int    AFS::try_to_cache(FILE * fp, char *name, int mode, int t)
   
 
   name += 2;
+  if(*name==0)
+          return 0;
   if ((mode & S_IFDIR) == 0)
     {
       b = strrchr(name, '/');
@@ -979,12 +990,12 @@ int    AFS::try_to_cache(FILE * fp, char *name, int mode, int t)
           }
           if(o==NULL)
           {
-                  o=cache_alloc(S_DTree);
+                  o=(DTree*)cache_alloc(S_DTree);
                   if(b)
                           l=b-s+1;
                   else
                           l=strlen(s)+1;
-                  o->name=cache_alloc(l);
+                  o->name=(char*)cache_alloc(l);
                   o->init(s,mode,t);
                   o->thislevel=obj->sublevel;
                   obj->sublevel=o;
@@ -1188,15 +1199,15 @@ int    AFS::reread()
   int    coun, c, ct = 0, mode, sl, i;
   char   name[512];
   char  *fname;
-  char   size[20];
   char   attrchr[20];
   char  *w;
-  char   strtmp[PATH_MAX];
-  char   lbuf1[PATH_MAX];
-  char   lbuf2[PATH_MAX];
+  char   strtmp[L_MAXPATH];
+  char   lbuf1[L_MAXPATH];
+  char   lbuf2[L_MAXPATH];
   int    fsiz;
   struct tm tm;
-  time_t t;
+  time_t tt;
+  time_t t=0;
   Namer *namer=NULL,*n,*n2;
   DTree *dt;
   
@@ -1209,12 +1220,14 @@ int    AFS::reread()
       return 0;
     }
 
+  signal(SIGCHLD,SIG_DFL);
   fp = popen(strtmp, "r");
   if (fp == NULL)
     {
       fclose(fp2);
       unlink(listpath);
       vfs_error(sp->name, "No specified executable for this AFS");
+      set_cmdchild_signal();
       return 0;
     }
   create_infowin(sp->name);
@@ -1223,7 +1236,8 @@ int    AFS::reread()
   sp->skip_header(fp);
   coun = 0;
   attrchr[0] = 0;
-  memset(&tm, 0, sizeof(tm));
+  time(&tt);
+  memcpy(&tm, localtime(&tt), sizeof(tm));
   while ((w = sp->getword(fp, coun)) != NULL)
     {
       bmark->animate();
@@ -1237,8 +1251,16 @@ int    AFS::reread()
       else if (c == sp->ddate)
         parse_date(tm, w);
       else if (c == sp->dtime) {
-        sscanf(w, "%d:%d:%d", &tm.tm_hour, &tm.tm_min, &tm.tm_sec);
-        tm.tm_isdst = -1;
+        if(strchr(w,':'))  //Is is time format or may be it is Year
+        {
+                sscanf(w, "%d:%d:%d", &tm.tm_hour, &tm.tm_min, &tm.tm_sec);
+                tm.tm_isdst = -1;
+        } else        //Yes, this is year, not time  (Some tar's use such technique)
+        {
+          sscanf(w, "%d", &tm.tm_year);
+          if (tm.tm_year > 1900)
+          tm.tm_year -= 1900;
+        }
       } else if (c == sp->dmonth)
         parse_month(tm, w);
       else if (c == sp->dyear) {
@@ -1261,14 +1283,13 @@ int    AFS::reread()
           prefix[i] = 0;
           if (i != 0 && prefix[i - 1] == '.')
             prefix[i - 1] = 0;
-          convert_attributes(mode, fsiz, attrchr);
+          convert_attributes(mode, fsiz, attrchr,name);
           t = mktime(&tm);
           if (t == -1)
             t = 0;
-          memset(&tm, 0, sizeof(tm));
+          memcpy(&tm, localtime(&tt), sizeof(tm));
           fname = gen_fullname(name);
           
-          
           if(mode & S_IFLNK)
           {
                   n=new Namer;
@@ -1277,12 +1298,6 @@ int    AFS::reread()
                   n2=new Namer(lbuf1,(FList*)n);
                   n2->next=namer;
                   namer=n2;
-
-/*                  sl = get_sublevel(lbuf1, mode);
-                  if ((mode & S_IFDIR) == 0)
-                    fprintf(fp2, "%d %X %d %d %s\n", sl, mode, fsiz, t, fname);
-                  try_to_cache(fp2, lbuf1, mode);
-*/
           } else
           {
                   sl = get_sublevel(name, mode);
@@ -1294,6 +1309,7 @@ int    AFS::reread()
         }
     }
   pclose(fp);
+  set_cmdchild_signal();
   while(namer)
   {
           n=namer;
@@ -1301,7 +1317,7 @@ int    AFS::reread()
           strcpy(lbuf2,n->name);
           upper_path(lbuf2);
           construct_full_link(lbuf2,n2->name);
-          dt=find_in_cache(lbuf2+2);
+          dt=(DTree*)find_in_cache(lbuf2+2);
           if(dt)
           {
                     sl=get_sublevel(n->name,0);
@@ -1326,7 +1342,7 @@ int    AFS::reread()
 int    AFS::direc(char *dir_ch)
 {
   FList *ol;
-  int    ct = 0, mode=0;
+  int    mode=0;
   FILE  *fp;
   int    coun;
   char   name[800];
@@ -1338,7 +1354,8 @@ int    AFS::direc(char *dir_ch)
   Namer *namer=NULL,*n;
   char *to_dir=this->to_dir;
   int linkcoun=0,l=strlen(to_dir);
-
+  
+  
   while(l>2 && strncmp(to_dir,"..",2)==0)
   {
           sublevel--;
@@ -1402,14 +1419,14 @@ int    AFS::direc(char *dir_ch)
           {
             if (hide_hidden && name[2] == '.')
               continue;
-            ol = new_alloc(S_FList);
+            ol = (FList*)new_alloc(S_FList);
             if(mode & S_IFLNK)
             {
                     breakdown_link(name, lbuf1, lbuf2);
                     ol->init(get_lastname(lbuf1), mode, fsiz, getuid(), getgid(), t);
                     if((mode & S_IFDIR)==S_IFDIR)
                     {
-                            ol->link=new_alloc(S_FList);
+                            ol->link=(FList*)new_alloc(S_FList);
                             ol->link->init(lbuf2,ol->mode,0,0,0,t);
                     } else
                     {
@@ -1420,16 +1437,16 @@ int    AFS::direc(char *dir_ch)
                     }
             } else
                     ol->init(get_lastname(name), mode, fsiz, getuid(), getgid(), t);
-            ol->mode&=~S_SELECT;
+            ol->options &= ~S_SELECT;
             if (mode & S_IFDIR)
               dl.add(ol);
             else
               {
                 fl.add(ol);
                 if (ext_find(ol->name) != -1)
-                  ol->mode |= S_EXTEND;
+                  ol->options |= S_EXTEND;
                 else if (is_it_afs_file(ol->name))
-                  ol->mode |= S_EXTEND;
+                  ol->options |= S_EXTEND;
               }
           }
     }
@@ -1441,7 +1458,7 @@ int    AFS::direc(char *dir_ch)
         struct stat st;
         while(n)
         {
-              ol=new_alloc(S_FList);
+              ol=(FList*)new_alloc(S_FList);
               if(flist_find_by_name(fl.next,n->name,&st))
               {
                       ol->init(n->name, st.st_mode, st.st_size, st.st_uid, st.st_gid, st.st_mtime);
@@ -1489,11 +1506,29 @@ int    AFS::direc(char *dir_ch)
   }
   
   bmark->animate();
-  ol = new_alloc(S_FList);
+  ol = (FList*)new_alloc(S_FList);
   ol->init("..", (0777 | S_IFDIR), 0, getuid(), getgid(), 0);
   simple_flist_add(&dl,ol);
-  ol = new_alloc(S_FList);
+  ol = (FList*)new_alloc(S_FList);
   ol->init(".", (0777 | S_IFDIR), 0, getuid(), getgid(), 0);
   simple_flist_add(&dl,ol);
+  
   return 1;
 }
+
+void   try_clean_afs_cache()
+{
+  char   strtmp2[128];
+  if (panel->vfs->fstype == AFS_TYPE || panel->panel2->vfs->fstype == AFS_TYPE)
+  {
+    simple_mes("Error", "Exit from archive before cleaning cache!");
+    return;
+  }
+  sprintf(strtmp2, "rm -rf '%s'/.%d*", syspath, getpid());
+  if (psystem(strtmp2) == 0)
+    simple_mes("Report", "Archive cache is clean.");
+  else
+    simple_mes("Error", "Something wrong with AFS cache!!!");
+}
+
+
