@@ -54,7 +54,17 @@
 #define AChown 51
 #define ACleanCache 52
 #define AFtpLink 53
-#define AEmpty 54
+#define AInsertLeftDir 54
+#define AInsertRightDir 55
+#define ASelectFileMask 56
+#define ADeselectFileMask 57
+#define AMoveHome 58
+#define AMoveEnd 59
+#define AMovePageDn 60
+#define AMovePageUp 61
+#define AInodeInfo 62
+#define AQuickFInfo 63
+#define AEmpty 64
 
 #define Alt  250
 #define Ctrl 251
