@@ -1,6 +1,6 @@
 /****************************************************************************
 *  Copyright (C) 1997 by Leo Khramov
-*  email:   leo@unix1.jinr.dubna.su
+*  email:   leo@xnc.dubna.su
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -31,14 +31,21 @@
 #include "box.xbm"
 #include "image/image.h"
 #include "qhelp.h"
+#include "au/au_sup.h"
+#include "c_externs.h"
+#include "internals.h"
+#include "xnimlib.h"
+#include "pluginman.h"
+
 #include <X11/cursorfont.h>
 
-extern Cursor cdnd1, cdnd2;
 extern Lister *dnd_creator;
 extern int dnd_startx, dnd_starty;
 extern VFS *define_vfs(char *type, char *d);
 extern void senddir(char *d);
-extern char *syspath;
+extern int layout;
+
+
 
 Cursor rw_cur;
 #define        STICKY_CENTER   20
@@ -48,15 +55,28 @@ char  *fschr[] =
 {"DFS", "ARC", "FTP"};
 int    fsmax = 3;
 
-Pixmap recyclepix = 0;
-Pixmap recyclemask = 0;
+Pixmap       recyclepix = 0;
+Pixmap       recyclemask = 0;
 unsigned int recycle_l, recycle_h;
-Pixmap pixrecycle[4];
-Pixmap maskrecycle[4];
+Pixmap       pixrecycle[4]={0,0,0,0};
+Pixmap       maskrecycle[4]={0,0,0,0};
 unsigned int l_recycle[4], h_recycle[4];
-int    cur_recycle = 0;
-extern int layout;
-extern void urect(Window w, GC & gcw, int x, int y, int l, int h);
+int          cur_recycle = 0;
+
+
+
+char *vfs_iname(char *vfsname, char *path)
+{
+ if(*vfsname!='A')
+         return vfsname;
+ SUP *sp=find_support(path);
+ if(sp)
+         return sp->name;
+ return vfsname;
+}
+
+
+
 // *INDENT-OFF*        
 BookMark::BookMark(int il, int ih):Gui()
 // *INDENT-ON*        
@@ -70,15 +90,16 @@ BookMark::BookMark(int il, int ih):Gui()
   hflg = 0;
   dflg = 1;
   escfunc = NULL;
-  guitype = 18;
+  guitype = GUI_BOOKMARK;
   guiobj = NULL;
   maxbooks = 9;
   last_used = 1;
   percent = 50;
-  for (int i = 0; i < 9; i++)
+  for (int i = 0; i <= 9; i++)
     {
       act_books[i] = 0;
       books[i] = NULL;
+      flagpix[i]=0;
     }
   add_book(0, getenv("HOME"), DFS_TYPE);
 }
@@ -200,6 +221,12 @@ void   BookMark::del_book(int i)
     }
 }
 
+void   BookMark::clear_and_expose()
+{
+  XClearWindow(disp, w);
+  expose();
+}
+
 //Return VFS constructed from bookmark
 //NULL if empty
 VFS   *BookMark::get_vfs_by_coord(int iy)
@@ -213,47 +240,183 @@ VFS   *BookMark::get_vfs_by_coord(int iy)
   return define_vfs(fs[iy], books[iy]);
 }
 
+void   BookMark::free_pix()
+{
+   int i;
+   for(i=0;i<max_anims;i++)
+       if(flagpix[i]!=0)
+       {
+               XFreePixmap(disp,flagpix[i]);
+               flagpix[i]=0;
+       }
+   for(i=0;i<4;i++)
+       if(pixrecycle[i]!=0)
+       {
+               XFreePixmap(disp,pixrecycle[i]);
+               pixrecycle[i]=0;
+       }
+}
+             
+
+int   BookMark::load_pixmap(int idx)
+{
+  int    r_l, r_h;
+
+  if(vclass==PseudoColor)
+    return 0;
+
+  switch(idx)
+    {
+    case 0:
+    case 1:
+    case 2:
+    case 3:
+    case 4:
+    case 5:
+    case 6:
+
+      flagpix[idx] = LoadPixmapFromMem(flags_chr[idx], F_GIF, flagl, flagh,
+                                       CMP_AUTO,flags_sizes[idx]);
+      return 1;
+
+    case 7:
+      pixrecycle[0] = recyclepix = LoadPixmapFromMem(recycle_chr, F_GIF, r_l,
+                                                     r_h,CMP_AUTO,
+                                                     recycle_chr_size);
+      l_recycle[0] = recycle_l = (unsigned)r_l;
+      h_recycle[0] = recycle_h = (unsigned)r_h;
+      recyclemask = maskrecycle[0] = XCreateBitmapFromData(disp, Main, (char *)
+                                                           recmask_bits, 
+                                                           recmask_width, 
+                                                           recmask_height);
+      return 1;
+
+    case 8:
+      pixrecycle[1] = LoadPixmapFromMem(recycle2_chr, F_GIF, r_l, r_h,CMP_AUTO,
+                                        recycle2_chr_size);
+      l_recycle[1] = (unsigned)r_l;
+      h_recycle[1] = (unsigned)r_h;
+      maskrecycle[1] = XCreateBitmapFromData(disp, Main, (char *)rec2m_bits, 
+                                             rec2m_width, rec2m_height);
+      return 1;
+
+    case 9:
+      pixrecycle[2] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
+                                        recycle3_chr_size);
+      l_recycle[2] = (unsigned)r_l;
+      h_recycle[2] = (unsigned)r_h;
+      maskrecycle[2] = XCreateBitmapFromData(disp, Main, (char *)rec3m_bits, 
+                                             rec3m_width, rec3m_height);
+      return 1;
+
+    case 10:
+      pixrecycle[3] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
+                                        recycle3_chr_size);
+      l_recycle[3] = (unsigned)r_l;
+      h_recycle[3] = (unsigned)r_h;
+      maskrecycle[3] = XCreateBitmapFromData(disp, Main, (char *)rec4m_bits, 
+                                             rec4m_width, rec4m_height);
+      max_anims=3;       
+      return 0;
+
+
+    }
+  return 0;
+}
+
 void   BookMark::load_flags(int n)
 {
-  char   tmp[256];
   int    i = 0;
   flag_anim = 1;
   max_anims = n;
   int    r_l, r_h;
-  if (vclass != PseudoColor)
+  if (vclass != PseudoColor && !is_fast_load() && !is_back_load())
     {
-      sprintf(tmp, "%s/recycle", syspath);
-      pixrecycle[0] = recyclepix = LoadPixmap(tmp, F_AUTO, r_l, r_h);
+      pixrecycle[0] = recyclepix = LoadPixmapFromMem(recycle_chr, F_GIF, r_l,
+                                                     r_h,CMP_AUTO,
+                                                     recycle_chr_size);
       l_recycle[0] = recycle_l = (unsigned)r_l;
       h_recycle[0] = recycle_h = (unsigned)r_h;
-      fprintf(stderr, ".");
-      sprintf(tmp, "%s/recycle2", syspath);
-      pixrecycle[1] = LoadPixmap(tmp, F_AUTO, r_l, r_h);
+      show_dot();
+      pixrecycle[1] = LoadPixmapFromMem(recycle2_chr, F_GIF, r_l, r_h,CMP_AUTO,
+                                        recycle2_chr_size);
       l_recycle[1] = (unsigned)r_l;
       h_recycle[1] = (unsigned)r_h;
-      fprintf(stderr, ".");
-      sprintf(tmp, "%s/recycle3", syspath);
-      pixrecycle[2] = LoadPixmap(tmp, F_AUTO, r_l, r_h);
+      show_dot();
+      pixrecycle[2] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
+                                        recycle3_chr_size);
       l_recycle[2] = (unsigned)r_l;
       h_recycle[2] = (unsigned)r_h;
-      fprintf(stderr, ".");
-      sprintf(tmp, "%s/recycle4", syspath);
-      pixrecycle[3] = LoadPixmap(tmp, F_AUTO, r_l, r_h);
+      show_dot();
+      pixrecycle[3] = LoadPixmapFromMem(recycle3_chr, F_GIF, r_l, r_h,CMP_AUTO,
+                                        recycle3_chr_size);
       l_recycle[3] = (unsigned)r_l;
       h_recycle[3] = (unsigned)r_h;
-      fprintf(stderr, ".");
+      show_dot();
+      recyclemask = maskrecycle[0] = XCreateBitmapFromData(disp, Main, (char *)
+                                                           recmask_bits, 
+                                                           recmask_width, 
+                                                           recmask_height);
+      maskrecycle[1] = XCreateBitmapFromData(disp, Main, (char *)rec2m_bits, 
+                                             rec2m_width, rec2m_height);
+      maskrecycle[2] = XCreateBitmapFromData(disp, Main, (char *)rec3m_bits, 
+                                             rec3m_width, rec3m_height);
+      maskrecycle[3] = XCreateBitmapFromData(disp, Main, (char *)rec4m_bits, 
+                                             rec4m_width, rec4m_height);
+    } else
+    {
+      recyclepix = pixrecycle[0] = 
+        XCreatePixmapFromBitmapData(disp, Main, 
+                                    (char *)recycle_bits, recycle_width,
+                                    recycle_height,cols[0], 
+                                    keyscol[1], 
+                                    DefaultDepth(disp, DefaultScreen(disp)));
+      recycle_l = l_recycle[0] = recycle_width;
+      recycle_h = h_recycle[0] = recycle_height;
+      pixrecycle[1] = XCreatePixmapFromBitmapData(disp, Main, 
+                                                  (char *)recycle_bits, 
+                                                  recycle_width, 
+                                                  recycle_height,
+                                                  cols[0], keyscol[1], 
+                                                  DefaultDepth(disp, 
+                                                               DefaultScreen(disp)));
+      l_recycle[1] = recycle_width;
+      h_recycle[1] = recycle_height;
+      pixrecycle[2] = XCreatePixmapFromBitmapData(disp, Main, (char *)
+                                                  recycle_bits, recycle_width,
+                                                  recycle_height,
+                                                  cols[0], keyscol[1], 
+                                                  DefaultDepth(disp, DefaultScreen(disp)));
+      l_recycle[2] = recycle_width;
+      h_recycle[2] = recycle_height;
+      pixrecycle[3] = XCreatePixmapFromBitmapData(disp, Main, (char *)recycle_bits, recycle_width, recycle_height,
+              cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
+      l_recycle[3] = recycle_width;
+      h_recycle[3] = recycle_height;
+
+      recyclemask = maskrecycle[0] = XCreateBitmapFromData(disp, Main, (char *)box_bits, box_width, box_height);
+      maskrecycle[1] = XCreateBitmapFromData(disp, Main, (char *)box_bits, box_width, box_height);
+      maskrecycle[2] = XCreateBitmapFromData(disp, Main, (char *)box_bits, box_width, box_height);
+      maskrecycle[3] = XCreateBitmapFromData(disp, Main, (char *)box_bits, box_width, box_height);
+
     }
-  if (vclass != PseudoColor && allow_animation)
+
+  XSetClipMask(disp, gcm, recyclemask);
+  cur_recycle = 0;
+  XSetClipOrigin(disp, gcm, l / 2 - recycle_l / 2, h - recycle_h - 3);
+
+  if (vclass != PseudoColor && allow_animation && !is_fast_load() && !is_back_load())
     for (i = 0; i < n; i++)
       {
-        sprintf(tmp, "%s/flag%d.gif", syspath, i + 1);
-        flagpix[i] = LoadPixmap(tmp, F_AUTO, flagl, flagh);
+//        sprintf(tmp, "%s/flag%d.gif", syspath, i + 1);
+        flagpix[i] = LoadPixmapFromMem(flags_chr[i], F_GIF, flagl, flagh,
+                                       CMP_AUTO,flags_sizes[i]);
         if (flagpix[i] == 0)
           {
             flag_anim = 0;
             break;
           };
-        fprintf(stderr, ".");
+      show_dot();
       }
   if (i < n)
     {
@@ -261,28 +424,28 @@ void   BookMark::load_flags(int n)
       flag_anim = 1;
       flagpix[0] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagpix[1] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir1_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagpix[2] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir2_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagpix[3] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir3_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagpix[4] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir4_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagpix[5] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir5_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagpix[6] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir6_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagpix[7] = XCreatePixmapFromBitmapData(disp, Main, (char *)cir7_bits, cir_width, cir_height,
               cols[0], keyscol[1], DefaultDepth(disp, DefaultScreen(disp)));
-      fprintf(stderr, ".");
+      show_dot();
       flagl = (int)cir_width;
       flagh = (int)cir_height;
     }
@@ -293,7 +456,7 @@ void   BookMark::load_flags(int n)
 
 void   BookMark::animate()
 {
-  if (flag_anim && mapped)
+  if (flag_anim && mapped && allow_animation)
     {
       flag_coun++;
       if (flag_coun > 40)
@@ -311,13 +474,15 @@ void   BookMark::animate()
 
 void   BookMark::animate_moving(int i)
 {
+  if(!allow_animation)
+          return;
   int    ix = x + l - 1, iy = y + 25 + page_h * (i + 1) - 1;
   int    il = l - 1, ih = page_h - 1;
   int    bh = ih, bl = il;
   int    bx = ix, by = iy;
   int    istep = 0;
-  int    dx, dy = panel->y + 25 - by;
-  int    dl, dh = 25 - ih;
+  int    dx=0, dy = panel->y + 25 - by;
+  int    dl=0, dh = 25 - ih;
   int    oldl, oldh, oldx, oldy;
   switch (panel->lay)
     {
@@ -359,13 +524,15 @@ void   BookMark::animate_moving(int i)
 
 void   BookMark::animate_swapping(int i)
 {
+  if(!allow_animation)
+          return;
   int    ix = x + l - 1, iy = y + 25 + page_h * (i + 1) - 1;
   int    il = l - 1, ih = page_h - 1;
   int    bh = ih, bl = il;
   int    bx = ix, by = iy;
   int    istep = 0;
-  int    dx, dy = panel->y + 25 - by;
-  int    dl, dh = 25 - ih;
+  int    dx=0, dy = panel->y + 25 - by;
+  int    dl=0, dh = 25 - ih;
   int    oldl, oldh, oldx, oldy;
   int    oldl2, oldh2, oldx2, oldy2;
   int    dx2, dy2, dl2, dh2, ix2, iy2, il2, ih2, bx2, by2, bl2, bh2;
@@ -435,8 +602,11 @@ void   BookMark::blink_book(int n, int blinks)
     return;
   while (blinks)
     {
+/*XFR
       XSetForeground(disp, gcw, keyscol[1]);
       XFillRectangle(disp, w, gcw, 0, iy, l, page_h);
+*/
+      XClearArea(disp, w, 0, iy, l, page_h, 0);
       XSync(disp, 0);
       delay(150);
       if (n == last_used)
@@ -505,8 +675,7 @@ void   BookMark::draw_page(int n)
   char   str[3];
   str[0] = n + '1';
   str[1] = 0;
-  XSetForeground(disp, gcw, keyscol[1]);
-  XFillRectangle(disp, w, gcw, 0, iy, l, page_h);
+  XClearArea(disp, w, 0, iy, l, page_h, 0);
   if (n < 8)
     XCopyArea(disp, a1pix, w, gcw, 0, 0, a1_width, a1_height, 3, iy + 6);
   else
@@ -534,8 +703,7 @@ void   BookMark::draw_selected_page(int n)
   char   str[3];
   str[0] = n + '1';
   str[1] = 0;
-  XSetForeground(disp, gcw, keyscol[1]);
-  XFillRectangle(disp, w, gcw, 0, iy, l, page_h);
+  XClearArea(disp, w, 0, iy, l, page_h, 0);
   if (n < 8)
     XCopyArea(disp, a1pix, w, gcw, 0, 0, a1_width, a1_height, 3, iy + 6);
   else
@@ -565,9 +733,15 @@ void   BookMark::draw_selected_page(int n)
   XDrawLine(disp, w, gcw, l - 5, iy + page_h - 2, l - 2, iy + page_h - 5);
 }
 
-void   BookMark::create_listers(Lister ** l1, Lister ** l2)
+// ix - position in X coord
+// iy - position int Y coord
+// ny - width of down menu+commandline
+void   BookMark::create_listers(Lister ** l1, Lister ** l2, int ix, int iy, int ny)
 {
   int    mll;
+  listx=ix;
+  listy=iy;
+  listny=ny;
   if (allow_bookmark == 0)
     l = 0;
   rw = 0;
@@ -575,16 +749,18 @@ void   BookMark::create_listers(Lister ** l1, Lister ** l2)
     {
     case 1:                        //Vertical layout
 
-      mll = (Mainl - l) * percent / 100;
-      lst1 = new Lister(0, 20, mll - 1, Mainh - 63);
-      lst2 = new Lister(mll + 1, 20, (Mainl - l - mll) - 1, Mainh - 63);
+      mll = (Mainl - l) * percent / 100 - ix;
+      lst1 = guiplugin->new_Lister(ix, iy, mll - 1, Mainh  - ny - iy);
+      lst2 = guiplugin->new_Lister(ix + mll + 1, iy, (Mainl - l - mll) - 1 - ix, Mainh - ny -iy);
+      lst1->set_iname("LISTER1");
+      lst2->set_iname("LISTER2");
       lst2->side = 2;
 
       rwx = mll - 1;
-      rwy = 20;
+      rwy = iy;
       leftrx = (Mainl - l) * MIN_PERCENT / 100;
       rightrx = Mainl - l - leftrx;
-      rw = XCreateSimpleWindow(disp, parent, rwx, rwy, 2, Mainh - 63, 0, 0, keyscol[1]);
+      rw = XCreateSimpleWindow(disp, parent, rwx, rwy, 2, Mainh - ny- iy, 0, 0, keyscol[1]);
       gcrw = XCreateGC(disp, rw, 0, NULL);
       XSelectInput(disp, rw, PointerMotionHintMask |
                    ButtonPressMask | ExposureMask | ButtonReleaseMask | Button1MotionMask);
@@ -593,13 +769,15 @@ void   BookMark::create_listers(Lister ** l1, Lister ** l2)
 
       XFreeCursor(disp, rw_cur);
       rw_cur = XCreateFontCursor(disp, XC_sb_v_double_arrow);
-      mll = (Mainh - 63) * percent / 100;
-      lst1 = new Lister(0, 20, Mainl - l, mll - 1);
-      lst2 = new Lister(0, 20 + mll + 1, Mainl - l, Mainh - 64 - mll);
+      mll = (Mainh - ny - iy) * percent / 100;
+      lst1 = guiplugin->new_Lister(ix, iy, Mainl - l, mll - 1);
+      lst2 = guiplugin->new_Lister(ix, iy + mll + 1, Mainl - l, Mainh - 1 - ny - iy - mll);
+      lst1->set_iname("LISTER1");
+      lst2->set_iname("LISTER2");
       lst2->side = 2;
 
       rwx = 0;
-      rwy = 19 + mll;
+      rwy = iy -1 + mll;
       leftrx = (Mainh - 63) * MIN_PERCENT / 100;
       rightrx = Mainh - 63 - leftrx;
       rw = XCreateSimpleWindow(disp, parent, rwx, rwy, Mainl - l, 2, 0, 0, keyscol[1]);
@@ -609,8 +787,10 @@ void   BookMark::create_listers(Lister ** l1, Lister ** l2)
       break;
     case 2:                        //Page layout
 
-      lst1 = new Lister(0, 20, Mainl - l, Mainh - 63);
-      lst2 = new Lister(0, 20, Mainl - l, Mainh - 63);
+      lst1 = guiplugin->new_Lister(ix, iy, Mainl - l, Mainh - ny - iy);
+      lst2 = guiplugin->new_Lister(ix, iy, Mainl - l, Mainh - ny - iy);
+      lst1->set_iname("LISTER1");
+      lst2->set_iname("LISTER2");
       lst1->lay = 1;
       lst2->lay = 2;
       break;
@@ -673,24 +853,24 @@ void   BookMark::rebuild_listers()
   int    mll;
   if (layout == 1)
     {
-      mll = (Mainl - l) * percent / 100;
-      lst1->reconfigure_without_expose(0, 20, mll - 1, Mainh - 63);
-      lst2->reconfigure_without_expose(mll + 1, 20, Mainl - l - mll - 1, Mainh - 63);
+      mll = (Mainl - l) * percent / 100 - listx;
+      lst1->reconfigure_without_expose(listx, listy, mll - 1, Mainh - listy - listny);
+      lst2->reconfigure_without_expose(mll + 1 + listx, listy, Mainl - l - mll - 1, Mainh - listy - listny);
       rwx = mll - 1;
-      rwy = 20;
+      rwy = listy;
       leftrx = (Mainl - l) * MIN_PERCENT / 100;
       rightrx = Mainl - l - leftrx;
       XMoveResizeWindow(disp, rw, rwx, rwy, 2, h);
     }
   else if (layout == 0)
     {
-      mll = (Mainh - 63) * percent / 100;
-      lst1->reconfigure_without_expose(0, 20, Mainl - l, mll - 1);
-      lst2->reconfigure_without_expose(0, 20 + mll + 1, Mainl - l, Mainh - 64 - mll);
+      mll = (Mainh - listny - listy) * percent / 100;
+      lst1->reconfigure_without_expose(listx, listy, Mainl - l, mll - 1);
+      lst2->reconfigure_without_expose(listx, listy + mll + 1, Mainl - l, Mainh - 1 - listy - listny - mll);
       rwx = 0;
-      rwy = 19 + mll;
-      leftrx = (Mainh - 63) * MIN_PERCENT / 100;
-      rightrx = Mainh - 63 - leftrx;
+      rwy = listy - 1 + mll;
+      leftrx = (Mainh - listny - listy) * MIN_PERCENT / 100;
+      rightrx = Mainh - listny - listy - leftrx;
       XMoveResizeWindow(disp, rw, rwx, rwy, Mainl - l, 2);
     }
 }
@@ -699,6 +879,8 @@ void   BookMark::reconfigure(int ix, int iy, int il, int ih)
 {
   int    mll;
   h = ih;
+  listy=iy;
+  y=iy;
   page_h = (h - 75) / 9;
   maxy = 25 + maxbooks * page_h;
   if (allow_bookmark == 0)
@@ -708,29 +890,29 @@ void   BookMark::reconfigure(int ix, int iy, int il, int ih)
 
     case 1:
       mll = (Mainl - l) * percent / 100;
-      lst1->reconfigure(0, 20, mll - 1, Mainh - 63);
-      lst2->reconfigure(mll + 1, 20, Mainl - l - mll - 1, Mainh - 63);
+      lst1->reconfigure(0, iy, mll - 1, Mainh - listy - listny);
+      lst2->reconfigure(mll + 1, iy, Mainl - l - mll - 1, Mainh - listy - listny);
       rwx = mll - 1;
-      rwy = 20;
+      rwy = iy;
       leftrx = (Mainl - l) * MIN_PERCENT / 100;
       rightrx = Mainl - l - leftrx;
       XMoveResizeWindow(disp, rw, rwx, rwy, 2, h);
       rw_expose();
       break;
     case 0:
-      mll = (Mainh - 63) * percent / 100;
-      lst1->reconfigure(0, 20, Mainl - l, mll - 1);
-      lst2->reconfigure(0, 21 + mll, Mainl - l, Mainh - 64 - mll);
+      mll = (Mainh - listy - listny) * percent / 100;
+      lst1->reconfigure(0, iy, Mainl - l, mll - 1);
+      lst2->reconfigure(0, iy+1 + mll, Mainl - l, Mainh - 1 - listny - listy - mll);
       rwx = 0;
-      rwy = 20 + mll - 1;
-      leftrx = (Mainh - 63) * MIN_PERCENT / 100;
-      rightrx = Mainh - 63 - leftrx;
+      rwy = iy + mll - 1;
+      leftrx = (Mainh - listy - listny) * MIN_PERCENT / 100;
+      rightrx = Mainh - listy - listny - leftrx;
       XMoveResizeWindow(disp, rw, rwx, rwy, Mainl - l, 2);
       rw_expose();
       break;
     case 2:
-      lst1->reconfigure(0, 20, Mainl - l, Mainh - 63);
-      lst2->reconfigure(0, 20, Mainl - l, Mainh - 63);
+      lst1->reconfigure(0, iy, Mainl - l, Mainh - listy - listny);
+      lst2->reconfigure(0, iy, Mainl - l, Mainh - listy - listny);
       break;
     };                                //-3
 
@@ -791,7 +973,7 @@ int    BookMark::is_in_bookmark(char *s)
 
 void   BookMark::switch_books(int i)
 {
-  int    typ;
+  int    typ=VFS_TYPE;
   if (allow_bookmark == 0)
     return;
   if (act_books[i] == 0)
@@ -845,7 +1027,7 @@ void   BookMark::show_dir_banner(int iy)
           if (k != pagenum && act_books[k])
             {
               pagenum = k;
-              qh.show_this_info(fs[k], books[k], -x, 53 + page_h * k);
+              qh.show_this_info(vfs_iname(fs[k], books[k]), books[k], -x, 53 + page_h * k);
               qh.show();
             }
 //    if(cur_recycle!=0) set_recycle_image(0);
@@ -881,7 +1063,7 @@ void   BookMark::click()
           expose();
           break;
         case MotionNotify:
-//   XQueryPointer(disp,w,&rrw,&cw,&rx,&ry,&cx,&cy,&kmask);
+          XQueryPointer(disp,w,&rrw,&cw,&rx,&ry,&cx,&cy,&kmask);
           rx = ev.xbutton.x;
           ry = ev.xbutton.y;
           kmask = ev.xbutton.state;
@@ -902,7 +1084,7 @@ void   BookMark::click()
                   if (k != pagenum && act_books[k])
                     {
                       pagenum = k;
-                      qh.show_this_info(fs[k], books[k], -x, 53 + page_h * k);
+                      qh.show_this_info(vfs_iname(fs[k], books[k]),books[k], -x, 53 + page_h * k);
                       qh.show();
                     }
                 }
@@ -973,7 +1155,7 @@ void   BookMark::click()
                   else
                     {
                       swap_books(last_used);
-                      qh.show_this_info(fs[last_used], books[last_used], -x, 53 + page_h * last_used);
+                      qh.show_this_info(vfs_iname(fs[last_used],books[last_used]), books[last_used], -x, 53 + page_h * last_used);
                       qh.show();
                     };
                 }
