@@ -1,6 +1,6 @@
 /****************************************************************************
 *  Copyright (C) 1996-98 by Leo Khramov
-*  email:     leo@unix1.jinr.dubna.su
+*  email:     leo@xnc.dubna.su
 *  
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-
+/* $Id: dfs.cxx,v 1.4 2000/12/22 06:12:28 leo Exp $ */
 //This file contains routines for Disk File System (DFS). This is default FS
 //which uses on normal mounted partitions
 
@@ -20,10 +20,13 @@
 #include "panel.h"
 #include "query_windows.h"
 #include "infowin.h"
+#include "inodewin.h"
+#include "c_externs.h"
+#include "bookmark.h"
+#include "systemfuncs.h"
+
+int    symlink_as_is = 1;        //Copy symlink as is (symlink as symlink, not a copy of file it points to) 
 
-// These should go into some header file...
-extern "C" void process_x_event(XEvent *);
-extern "C" int psystem2(char *str,...);
 
 //Internal routine for copying single file (FList*) to directory (vfs->curdir).
 //This routine will be called only for DFS->DFS copying.
@@ -46,9 +49,9 @@ static int internal_copy_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
     bsize = 31072;
   if (dfs->curdir[l - 1] != '/')
     {
-      stat(dfs->curdir, &st);
-      if (S_ISDIR(st.st_mode) == 0)
-        do_add = 0;
+      if(stat(dfs->curdir, &st)==-1 ||
+         (!S_ISDIR(st.st_mode)))
+                do_add = 0;
     }
   if (do_add)
     add_path_content(dfs->curdir, o->name);
@@ -56,15 +59,16 @@ static int internal_copy_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
   // 'Symlink as is' copy part.
   if (symlink_as_is)
     {
-      lstat(o->name, &st);
-      if (S_ISLNK(st.st_mode))
+      if(lstat(o->name, &st)!=-1 &&
+         S_ISLNK(st.st_mode))
         {
-          buf = (char *)alloca(2*PATH_MAX);
-          if ((siz = readlink(o->name, buf, 2*PATH_MAX)) == -1)
+          buf = new char[2*L_MAXPATH];
+          if ((siz = readlink(o->name, buf, 2*L_MAXPATH)) == -1)
             {
               errno2mes();
               if (do_add)
                 upper_path(dfs->curdir);
+              delete buf;
               return 0;
             }
           buf[siz] = 0;
@@ -78,6 +82,7 @@ static int internal_copy_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
                       errno2mes();
                       if (do_add)
                         upper_path(dfs->curdir);
+                      delete buf;
                       return 0;
                     }
                   if (symlink(buf, dfs->curdir) == -1)        //Link again with new pointer
@@ -86,12 +91,14 @@ static int internal_copy_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
                       errno2mes();
                       if (do_add)
                         upper_path(dfs->curdir);
+                      delete buf;
                       return 0;
                     }
                 }
             }
           if (do_add)
             upper_path(dfs->curdir);
+          delete buf;
           return 1;
         }
     }
@@ -134,7 +141,7 @@ static int internal_copy_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
               process_x_event(&ev);
               XFlush(disp);
             }
-          disable_reread=1;
+          disable_reread=0;
         }
       close(fp1);
       close(fp2);
@@ -157,6 +164,11 @@ static int internal_copy_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
       return 1;
     }
   errno2mes();
+  if(fp1!=-1)
+    close(fp1);
+  if(fp2!=-1)
+    close(fp2);
+  unlink(dfs->curdir);
   if (do_add)
     upper_path(dfs->curdir);
   return 0;
@@ -167,7 +179,7 @@ static int internal_move_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
   struct stat st;
   XEvent ev;
   int    l = strlen(dfs->curdir), do_add = 1, ret;
-
+/*
   disable_reread=1;
   while (XPending(disp))        //Look for XEvent, if yes then processing it and after that go to move..
 
@@ -177,7 +189,7 @@ static int internal_move_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
       XFlush(disp);
     }
   disable_reread=0;
-
+*/
   if (S_ISLNK(o->mode))                //First of all looking for a symlink
     {
       char buf[1024];
@@ -187,19 +199,29 @@ static int internal_move_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
           return 0;
       }
       buf[ret]=0;
-      add_path_content(dfs->curdir, o->name);
-      if(symlink(buf,dfs->curdir)==-1)
+      if(stat(dfs->curdir, &st)!=-1 && (st.st_mode & S_IFDIR))
       {
+              add_path_content(dfs->curdir, o->name);
+              if(symlink(buf,dfs->curdir)==-1)
+              {
+                      upper_path(dfs->curdir);
+                      errno2mes();
+                      return 0;
+              }
               upper_path(dfs->curdir);
-              errno2mes();
-              return 0;
-      }
-      upper_path(dfs->curdir);
-      if(unlink(o->name)==-1)
+              if(unlink(o->name)==-1)
+              {
+                      errno2mes();
+                      return 0;
+              }
+      } else
       {
-              errno2mes();
-              return 0;
-      }
+        ret = rename(o->name, dfs->curdir);
+        upper_path(dfs->curdir);
+        if (ret == -1)
+           errno2mes();
+        return ret == -1 ? 0 : 1;
+      }         
       return 1;
    }
 
@@ -214,9 +236,9 @@ static int internal_move_file(FList * o, DFS * dfs, dev_t dev, ino_t inode)
     }
   if (dfs->curdir[l - 1] != '/')
     {
-      stat(dfs->curdir, &st);
-      if (S_ISDIR(st.st_mode) == 0)
-        do_add = 0;
+      if(stat(dfs->curdir, &st)==-1 ||
+         S_ISDIR(st.st_mode) == 0)
+	 do_add = 0;
     }
   if (do_add)
     add_path_content(dfs->curdir, o->name);
@@ -253,7 +275,7 @@ char  *DFS::get_dir_header()
 
 int    DFS::make_fullpath()
 {
-  char   tstr[PATH_MAX];
+  char   tstr[L_MAXPATH];
   int    l;
 
 // *INDENT-OFF*        
@@ -271,7 +293,6 @@ int    DFS::make_fullpath()
 int    DFS::direc(char *dir_ch)
 {
   FList *ol;
-  int    ct = 0;
   DIR   *d = NULL;
   struct dirent *dr;
   struct stat st;
@@ -279,7 +300,7 @@ int    DFS::direc(char *dir_ch)
   int dirf;
   int mmode;
   FList *o;
-  int l,i;
+  int l;
   char lbuf[FLIST_NAME];
 
   d = opendir(dir_ch);
@@ -300,8 +321,8 @@ int    DFS::direc(char *dir_ch)
              stat(dr->d_name,&st);
              st.st_mode|=S_IFLNK;
       }
-      ol = new_alloc(S_FList);
-      ol->init(dr->d_name, st.st_mode, st.st_size, st.st_uid, st.st_gid, st.st_mtime);
+      ol =(FList*) new_alloc(S_FList);
+      ol->init(dr->d_name, st.st_mode, st.st_size, st.st_uid, st.st_gid, st.st_mtime, &st);
       if(st.st_mode & S_IFLNK)
       {
                      l= ::readlink(ol->name,lbuf,FLIST_NAME);
@@ -309,47 +330,38 @@ int    DFS::direc(char *dir_ch)
                      {
                              lbuf[l]=0;
                              stat(ol->name,&st);
-                             o = new_alloc(S_FList);
-                             o->init(lbuf, st.st_mode, st.st_size, st.st_uid, st.st_gid, st.st_mtime);
+                             o =(FList*) new_alloc(S_FList);
+                             o->init(lbuf, st.st_mode, st.st_size, st.st_uid, st.st_gid, st.st_mtime, &st);
                              ol->link=o;
                      } else
                      {
-                             o = new_alloc(S_FList);
+                             o = (FList*)new_alloc(S_FList);
                              sprintf(lbuf,"Readlink: %s", strerror(errno));
                              o->init(lbuf, 0, 0, 0, 0, st.st_mtime);
                              ol->link=o;
                      }
       }
+
       if (st.st_mode & S_IFDIR)
         dl.add(ol);
       else
         {
           fl.add(ol);
           if (ext_find(ol->name) != -1)
-            ol->mode |= S_EXTEND;
+            ol->options |= S_EXTEND;
           else if (is_it_afs_file(ol->name))
-            ol->mode |= S_EXTEND;
+            ol->options |= S_EXTEND;
         }
     }
   closedir(d);
 
   stat("..", &st);
   bmark->animate();
-  fsiz = st.st_size;
-  if (S_ISDIR(st.st_mode))
-    dirf = 1;
-  else
-    dirf = 0;
-  mmode = st.st_mode & 0777;
-  lstat(dr->d_name, &st);
-  if (dirf)
-    st.st_mode |= S_IFDIR;
-  st.st_mode = st.st_mode & 037777777000 | mmode;
-  ol = new_alloc(S_FList);
-  ol->init("..", st.st_mode, fsiz, st.st_uid, st.st_gid, st.st_mtime);
-
+  ol = (FList*)new_alloc(S_FList);
+  ol->init("..", st.st_mode, st.st_size, st.st_uid, st.st_gid, st.st_mtime, &st);
   simple_flist_add(&dl, ol);
-  ol = new_alloc(S_FList);
+
+  ol = (FList*)new_alloc(S_FList);
   ol->init(".", S_IFDIR, 0, st.st_uid, st.st_gid, st.st_mtime);
   simple_flist_add(&dl, ol);
 
@@ -357,24 +369,54 @@ int    DFS::direc(char *dir_ch)
    ol=dl.next;
    while(ol!=next)
    {
-   fprintf(stderr,"Dir: %s\n",ol->name);
-   ol=ol->next;
+     xncdprintf(("DFS::direc() Dir: %s\n",ol->name));
+     ol=ol->next;
    }
-   fprintf(stderr,"-----------------------------------\n");
+   xncdprintf(("-----------------------------------\n"));
  */
 
+  magic_scanner();
   return 1;
 }
 
+int DFS::magic_scan()
+{
+ char tmppath[L_MAXPATH];
+ FList *o=dl.next->next;
+ if(magic_need_scan)
+     return 0;
+ options|=MAGIC_WORK;
+ while(o)
+ {
+     process_X();
+     if((options & MAGIC_WORK)==0)
+     {
+         xncdprintf(("DFS::magic_scan() Magic break work\n"));
+         return 0;
+     }
+     if(o->magic[0]==0 || o->magic[0]==' ')
+     {
+         if(strcmp(o->name, ".."))
+         {
+           sprintf(tmppath, "%s/%s", curdir, o->name);
+           o->add_magic(magic_process(tmppath, &o->st));
+         }
+     }
+     o=o->next;
+ }
+ options&=~MAGIC_WORK;
+ return 1;
+}
+
 //Look for file in dir and answer 1 if it is exist
 int    DFS::is_file_exist(char *dir, char *file)
 {
-  char strtmp[PATH_MAX];
+  char strtmp[L_MAXPATH];
   struct stat dstat;
    
-  if (lstat(dir, &dstat) == -1)
+  if (stat(dir, &dstat) == -1)
     return 0;
-  if (strlen(dir)+strlen(file)+1 > PATH_MAX)
+  if (strlen(dir)+strlen(file)+1 > L_MAXPATH)
     return 0;
   if (S_ISDIR(dstat.st_mode))
     {
@@ -391,7 +433,7 @@ int    DFS::copy(FList * cur, VFS * vfs)
   int    r;
   struct stat dstat;
 #ifndef __FreeBSD__
-  char   mstr[PATH_MAX];
+  char   mstr[L_MAXPATH];
 #endif
   FList otmp;
 
@@ -399,8 +441,8 @@ int    DFS::copy(FList * cur, VFS * vfs)
     {
       if (vfs->fstype == DFS_TYPE)        //DFS->DFS copy part
         {
-          if (!ow_all && !dont_ask)
-            if (vfs->is_file_exist(vfs->curdir, cur->name))
+          if (!ow_all && !dont_ask &&
+              vfs->is_file_exist(vfs->curdir, cur->name))
               {
                 init_overwrite_query("Copy file", cur->name);
                 wait_for_query_done();
@@ -437,7 +479,7 @@ int    DFS::copy(FList * cur, VFS * vfs)
             }
         }                        //End of DFS->DFS copy part
 
-      else if (vfs->fstype == AFS_TYPE)                //DFS->AFS copy part
+      else if (vfs->fstype == AFS_TYPE || vfs->fstype==FTP_TYPE)                //DFS->AFS copy part
 
         {
        // We check existance here
@@ -484,7 +526,7 @@ int    DFS::move(FList * cur, VFS * vfs)
 {
   struct stat st;
   int    r = 0;
-  char   mstr[PATH_MAX];
+  char   mstr[L_MAXPATH];
   FList  otmp;
 
   if (vfs->is_move_supported())
@@ -502,7 +544,9 @@ int    DFS::move(FList * cur, VFS * vfs)
           ow_file = 0;
 
           lstat(cur->name, &st);
+          cur->options=(cur->options & (S_SELECT | S_EXTEND));
           cur->mode=st.st_mode;
+          
           bmark->animate();
           if (S_ISDIR(st.st_mode) && !S_ISLNK(st.st_mode))
             {
@@ -531,7 +575,7 @@ int    DFS::move(FList * cur, VFS * vfs)
 
 int    DFS::copydir(FList * cur, VFS * vfs, mode_t mode, char *mstr)
 {
-  int    dcoun;
+  int    dcoun = 0;
   int    do_add = 0;
   DIR   *d;
   struct dirent *dr;
@@ -542,7 +586,7 @@ int    DFS::copydir(FList * cur, VFS * vfs, mode_t mode, char *mstr)
     do_add = 1;
   if (do_add)
     add_path_content(vfs->curdir, cur->name);
-  if (vfs->mkdir(vfs->curdir, mode | 0200) == -1)        //Create remote dir
+  if (vfs->mkdir(vfs->curdir, mode | 0700) == -1)        //Create remote dir
     {
        if(errno==EEXIST)
          {
@@ -574,10 +618,11 @@ int    DFS::copydir(FList * cur, VFS * vfs, mode_t mode, char *mstr)
     }
 
   while ((dr = readdir(d)) != NULL)        //Copy files only not subdirs
-
-    if (strcmp(dr->d_name, ".") != 0 && strcmp(dr->d_name, "..") != 0)        //Don't even think about copying this..
-      {
-        // *INDENT-OFF*        
+    {
+      dcoun++;
+      if (strcmp(dr->d_name, ".") != 0 && strcmp(dr->d_name, "..") != 0)        //Don't even think about copying this..
+	{
+	  // *INDENT-OFF*        
           if (::chdir(mstr) == -1)
             {
               errno2mes();
@@ -589,67 +634,64 @@ int    DFS::copydir(FList * cur, VFS * vfs, mode_t mode, char *mstr)
             }
         // *INDENT-ON*        
 
-        lstat(dr->d_name, &dstat);
-        if(S_ISLNK(dstat.st_mode) && !symlink_as_is)
-                stat(dr->d_name,&dstat);
-        if (S_ISDIR(dstat.st_mode) == 0)
-          {
-            strcpy(cur->name, dr->d_name);
-            cur->mode = dstat.st_mode;
-            cur->size = dstat.st_size;
-            bmark->animate();
-            to_infowin(cur->name);
-            if (copy(cur, vfs))
-              {
-                closedir(d);
-                upper_path(mstr);
-                if (do_add)
-                  upper_path(vfs->curdir);
-                return 255;
-              }
-          }
-        else
-          {
-            dcoun = telldir(d);
-            closedir(d);
-            bmark->animate();
-            strcpy(cur->name, dr->d_name);
-            if (copydir(cur, vfs, dstat.st_mode, mstr))
-              {
-                upper_path(mstr);
-                if (do_add)
-                  upper_path(vfs->curdir);
-                return 255;
-              }
-            else
-              {
-// *INDENT-OFF*        
-                if (::chdir(mstr) == -1)
-                  {
-                    errno2mes();
-                    upper_path(mstr);
-                    if (do_add)
-                      upper_path(vfs->curdir);
-                    return 255;
-                  };
-// *INDENT-ON*        
-
-
-                d = opendir(mstr);
-                if (d == NULL)
-                  {
-                    errno2mes();
-                    upper_path(mstr);
-                    if (do_add)
-                      upper_path(vfs->curdir);
-                    return 255;
-                  };
-                seekdir(d, dcoun);
-              }
-          }
-        bmark->animate();
-      }
-
+	  lstat(dr->d_name, &dstat);
+	  if(S_ISLNK(dstat.st_mode) && !symlink_as_is)
+	    stat(dr->d_name,&dstat);
+	  if (S_ISDIR(dstat.st_mode) == 0)
+	    {
+	      strcpy(cur->name, dr->d_name);
+	      cur->mode = dstat.st_mode;
+	      cur->size = dstat.st_size;
+	      bmark->animate();
+	      to_infowin(cur->name);
+	      if (copy(cur, vfs))
+		{
+		  closedir(d);
+		  upper_path(mstr);
+		  if (do_add)
+		    upper_path(vfs->curdir);
+		  return 255;
+		}
+	    }
+	  else
+	    {
+	      closedir(d);
+	      bmark->animate();
+	      strcpy(cur->name, dr->d_name);
+	      if (copydir(cur, vfs, dstat.st_mode, mstr))
+		{
+		  upper_path(mstr);
+		  if (do_add)
+		    upper_path(vfs->curdir);
+		  return 255;
+		}
+	      else
+		{
+		  // *INDENT-OFF*        
+		  if (::chdir(mstr) == -1)
+		    {
+		      errno2mes();
+		      upper_path(mstr);
+		      if (do_add)
+			upper_path(vfs->curdir);
+		      return 255;
+		    };
+		  // *INDENT-ON*        
+		  d = opendir(mstr);
+		  if (d == NULL)
+		    {
+		      errno2mes();
+		      upper_path(mstr);
+		      if (do_add)
+			upper_path(vfs->curdir);
+		      return 255;
+		    };
+		  xnc_seekdir(d, dcoun);
+		}
+	    }
+	  bmark->animate();
+	}
+    }
 
   closedir(d);
   upper_path(mstr);
@@ -668,6 +710,13 @@ int    DFS::copydir(FList * cur, VFS * vfs, mode_t mode, char *mstr)
 }
 
 
+char*  DFS::magic_file_process(FList *fo)
+{
+    char *tmps=magic_process(fo->name, &fo->st);
+    fo->add_magic(tmps);
+    return tmps;
+}
+
 int    DFS::movedir(FList * cur, VFS * vfs, mode_t mode, char *mstr)
 {
   int    do_add = 0;
