@@ -6,8 +6,8 @@
 class FileBrowser:public Gui
 {
  public:
-  int x,y,ty,ffl;
-  uint l,h,tl;
+  int ty,ffl;
+  uint tl;
   int col,prflg,hflg;
   char *name;
   List *oldel;
@@ -22,7 +22,7 @@ class FileBrowser:public Gui
   int lmax,tm;
   void (*func)();
   FileBrowser(int ix,int iy,int il,int ih,char *iname,int icol,int hfl=0):Gui()
-   {x=ix;y=iy;l=il;h=ih;col=icol;name=iname;hflg=hfl;guitype=16;strcpy(filter,"*");fname[0]=0;
+   {x=ix;y=iy;l=il;h=ih;col=icol;name=iname;hflg=hfl;guitype=GUI_FBROWSE;strcpy(filter,"*");fname[0]=0;
     getcwd(curdir,800);func=NULL;
     };
   ~FileBrowser() {if(disp){XFreeGC(disp,gcw);XDestroyWindow(disp,w);};};
