@@ -7,17 +7,19 @@
 #include "gui.h"
 #include "vfs.h"
 #include "qhelp.h"
+#include "skin.h"
 
 class Switcher: public Gui
 {
  public:
-  int x,y,prflg,tx,ty,hflg,dflg;
-  uint l,h,tl;
+  int prflg,tx,ty,hflg,dflg;
+  uint tl;
   ulong col;
   char *name;
   Gui *arr[10];
   int maxarr,curarr;
   void (*escfunc)();
+  Sprite *skin, *skinpr;
   Switcher(int ix,int iy,int il,int ih);
   ~Switcher() {if(disp) XFreeGC(disp,gcw);hflg=0;dflg=0;};
   void set_escapefunc(void (*v)()) {escfunc=v;};
@@ -47,8 +49,9 @@ class FtpVisual: public Gui
   virtual void click();
   virtual void show();
   virtual void hide();
-  void show_tumb(int i, int ix);
-  void show_empty_tumb(int i, int ix);
+  virtual void reconfigure(int ix,int iy,int pl,int ph);
+  virtual void show_tumb(int i, int ix);
+  virtual void show_empty_tumb(int i, int ix);
   void refresh(FTP* fo);
   void rescan();
   void animate_moving(int);
