@@ -112,11 +112,11 @@
 #define JPEG_IMAGES
 #include "picinfo.h"
 #define INT32  int
-static int    quick_check PARM((byte*, int,int, byte*, byte*,byte*,byte*,int));
-static int    quick_quant PARM((byte*, int,int, byte*, byte*,byte*,byte*,int));
-static int    ppm_quant   PARM((byte *,int,int, byte*, byte*,byte*,byte*,int));
+static int    quick_check (byte*, int,int, byte*, byte*,byte*,byte*,int);
+static int    quick_quant (byte*, int,int, byte*, byte*,byte*,byte*,int);
+static int    ppm_quant   (byte *,int,int, byte*, byte*,byte*,byte*,int);
 
-static int    slow_quant  PARM((byte*, int,int, byte*, byte*,byte*,byte*,int));
+static int    slow_quant  (byte*, int,int, byte*, byte*,byte*,byte*,int);
 
 /****************************/
 void Init24to8()
@@ -242,7 +242,7 @@ static int quick_check(pic24, w,h, pic8, rmap,gmap,bmap, maxcol)
     if (high < low) { /* didn't find color in list, add it. */
       if (nc>=maxcol) return 0;
       xvbcopy((char *) &colors[low], (char *) &colors[low+1],
-	      (nc - low) * sizeof(u_long));
+              (nc - low) * sizeof(u_long));
       colors[low] = col;
       nc++;
     }
@@ -300,6 +300,9 @@ static int quick_quant(p24,w,h, p8, rmap,gmap,bmap, nc)
 #define GMASK      0xe0
 #define GSHIFT        3
 #define BMASK      0xc0
+#if defined(BSHIFT)
+#undef BSHIFT
+#endif
 #define BSHIFT        6
 
   byte *pp;
@@ -342,7 +345,7 @@ static int quick_quant(p24,w,h, p8, rmap,gmap,bmap, nc)
 
     if (i!=imax)   /* get next line */
       for (j=pwide3, tmpptr=nextline; j; j--)
-	*tmpptr++ = (int) *p24++;
+        *tmpptr++ = (int) *p24++;
     
     for (j=0, thisptr=thisline, nextptr=nextline; j<w; j++,pp++) {
       r1 = *thisptr++;  g1 = *thisptr++;  b1 = *thisptr++;
@@ -350,7 +353,7 @@ static int quick_quant(p24,w,h, p8, rmap,gmap,bmap, nc)
       
       /* choose actual pixel value */
       val = (((r1&RMASK)>>RSHIFT) | ((g1&GMASK)>>GSHIFT) | 
-	     ((b1&BMASK)>>BSHIFT));
+             ((b1&BMASK)>>BSHIFT));
       *pp = val;
       
       /* compute color errors */
@@ -360,28 +363,28 @@ static int quick_quant(p24,w,h, p8, rmap,gmap,bmap, nc)
       
       /* Add fractions of errors to adjacent pixels */
       if (j!=jmax) {  /* adjust RIGHT pixel */
-	thisptr[0] += (r1*7) / 16;
-	thisptr[1] += (g1*7) / 16;
-	thisptr[2] += (b1*7) / 16;
+        thisptr[0] += (r1*7) / 16;
+        thisptr[1] += (g1*7) / 16;
+        thisptr[2] += (b1*7) / 16;
       }
       
-      if (i!=imax) {	/* do BOTTOM pixel */
-	nextptr[0] += (r1*5) / 16;
-	nextptr[1] += (g1*5) / 16;
-	nextptr[2] += (b1*5) / 16;
+      if (i!=imax) {        /* do BOTTOM pixel */
+        nextptr[0] += (r1*5) / 16;
+        nextptr[1] += (g1*5) / 16;
+        nextptr[2] += (b1*5) / 16;
 
-	if (j>0) {  /* do BOTTOM LEFT pixel */
-	  nextptr[-3] += (r1*3) / 16;
-	  nextptr[-2] += (g1*3) / 16;
-	  nextptr[-1] += (b1*3) / 16;
-	}
+        if (j>0) {  /* do BOTTOM LEFT pixel */
+          nextptr[-3] += (r1*3) / 16;
+          nextptr[-2] += (g1*3) / 16;
+          nextptr[-1] += (b1*3) / 16;
+        }
 
-	if (j!=jmax) {  /* do BOTTOM RIGHT pixel */
-	  nextptr[3] += (r1)/16;
-	  nextptr[4] += (g1)/16;
-	  nextptr[5] += (b1)/16;
-	}
-	nextptr += 3;
+        if (j!=jmax) {  /* do BOTTOM RIGHT pixel */
+          nextptr[3] += (r1)/16;
+          nextptr[4] += (g1)/16;
+          nextptr[5] += (b1)/16;
+        }
+        nextptr += 3;
       }
     }
   }
@@ -443,9 +446,9 @@ typedef struct { pixval r, g, b; } pixel;
 
 #define PPM_DEPTH(newp,p,oldmaxval,newmaxval) \
     PPM_ASSIGN( (newp), \
-	        (int) PPM_GETR(p) * (newmaxval) / ((int)oldmaxval), \
-	        (int) PPM_GETG(p) * (newmaxval) / ((int)oldmaxval), \
-	        (int) PPM_GETB(p) * (newmaxval) / ((int)oldmaxval) )
+                (int) PPM_GETR(p) * (newmaxval) / ((int)oldmaxval), \
+                (int) PPM_GETG(p) * (newmaxval) / ((int)oldmaxval), \
+                (int) PPM_GETB(p) * (newmaxval) / ((int)oldmaxval) )
 
 
 /* Luminance macro. */
@@ -463,13 +466,13 @@ typedef struct { pixval r, g, b; } pixel;
 
 typedef struct chist_item* chist_vec;
 struct chist_item { pixel color;
-			int value;
-		      };
+                        int value;
+                      };
 
 typedef struct chist_list_item* chist_list;
 struct chist_list_item { struct chist_item ch;
-			     chist_list next;
-			   };
+                             chist_list next;
+                           };
 
 typedef chist_list* chash_table;
 
@@ -492,25 +495,25 @@ struct box {
 #define HASH_SIZE 6553
 
 #define ppm_hashpixel(p) ((((int) PPM_GETR(p) * 33023 +    \
-			    (int) PPM_GETG(p) * 30013 +    \
-			    (int) PPM_GETB(p) * 27011) & 0x7fffffff)   \
-			  % HASH_SIZE)
+                            (int) PPM_GETG(p) * 30013 +    \
+                            (int) PPM_GETB(p) * 27011) & 0x7fffffff)   \
+                          % HASH_SIZE)
 
 
 
 /*** function defs ***/
 
-static chist_vec   mediancut        PARM((chist_vec, int, int, int, int));
-static int         redcompare       PARM((const void *, const void *));
-static int         greencompare     PARM((const void *, const void *));
-static int         bluecompare      PARM((const void *, const void *));
-static int         sumcompare       PARM((const void *, const void *));
-static chist_vec   ppm_computechist PARM((pixel **, int,int,int,int *));
-static chash_table ppm_computechash PARM((pixel **, int,int,int,int *));
-static chist_vec   ppm_chashtochist PARM((chash_table, int));
-static chash_table ppm_allocchash   PARM((void));
-static void        ppm_freechist    PARM((chist_vec));
-static void        ppm_freechash    PARM((chash_table));
+static chist_vec   mediancut        (chist_vec, int, int, int, int);
+static int         redcompare       (const void *, const void *);
+static int         greencompare     (const void *, const void *);
+static int         bluecompare      (const void *, const void *);
+static int         sumcompare       (const void *, const void *);
+static chist_vec   ppm_computechist (pixel **, int,int,int,int *);
+static chash_table ppm_computechash (pixel **, int,int,int,int *);
+static chist_vec   ppm_chashtochist (chash_table, int);
+static chash_table ppm_allocchash   (void);
+static void        ppm_freechist    (chist_vec);
+static void        ppm_freechash    (chash_table);
 
 
 /****************************************************************************/
@@ -572,7 +575,7 @@ static int ppm_quant(pic24, cols, rows, pic8, rmap, gmap, bmap, newcolors)
 
     for (row=0; row<rows; ++row)
       for (col=0, pP=pixels[row]; col<cols; ++col, ++pP)
-	PPM_DEPTH( *pP, *pP, maxval, newmaxval );
+        PPM_DEPTH( *pP, *pP, maxval, newmaxval );
     maxval = newmaxval;
   }
 
@@ -609,37 +612,37 @@ static int ppm_quant(pic24, cols, rows, pic8, rmap, gmap, bmap, newcolors)
 
       hash = ppm_hashpixel(*pP);
       for (chl = cht[hash];  chl;  chl = chl->next)
-	if (PPM_EQUAL(chl->ch.color, *pP)) {index = chl->ch.value; break;}
+        if (PPM_EQUAL(chl->ch.color, *pP)) {index = chl->ch.value; break;}
 
       if (!chl /*index = -1*/) {/* No; search colormap for closest match. */
-	register int i, r1, g1, b1, r2, g2, b2;
-	register long dist, newdist;
+        register int i, r1, g1, b1, r2, g2, b2;
+        register long dist, newdist;
 
-	r1 = PPM_GETR( *pP );
-	g1 = PPM_GETG( *pP );
-	b1 = PPM_GETB( *pP );
-	dist = 2000000000;
+        r1 = PPM_GETR( *pP );
+        g1 = PPM_GETG( *pP );
+        b1 = PPM_GETB( *pP );
+        dist = 2000000000;
 
-	for (i=0; i<newcolors; i++) {
-	  r2 = PPM_GETR( colormap[i].color );
-	  g2 = PPM_GETG( colormap[i].color );
-	  b2 = PPM_GETB( colormap[i].color );
+        for (i=0; i<newcolors; i++) {
+          r2 = PPM_GETR( colormap[i].color );
+          g2 = PPM_GETG( colormap[i].color );
+          b2 = PPM_GETB( colormap[i].color );
 
-	  newdist = ( r1 - r2 ) * ( r1 - r2 ) +
-	            ( g1 - g2 ) * ( g1 - g2 ) +
-	            ( b1 - b2 ) * ( b1 - b2 );
+          newdist = ( r1 - r2 ) * ( r1 - r2 ) +
+                    ( g1 - g2 ) * ( g1 - g2 ) +
+                    ( b1 - b2 ) * ( b1 - b2 );
 
-	  if (newdist<dist) { index = i;  dist = newdist; }
-	}
+          if (newdist<dist) { index = i;  dist = newdist; }
+        }
 
-	hash = ppm_hashpixel(*pP);
-	chl = (chist_list) malloc(sizeof(struct chist_list_item));
-	if (!chl) {fprintf(stderr,"ran out of memory adding to hash table");return 0;};
+        hash = ppm_hashpixel(*pP);
+        chl = (chist_list) malloc(sizeof(struct chist_list_item));
+        if (!chl) {fprintf(stderr,"ran out of memory adding to hash table");return 0;};
 
-	chl->ch.color = *pP;
-	chl->ch.value = index;
-	chl->next = cht[hash];
-	cht[hash] = chl;
+        chl->ch.color = *pP;
+        chl->ch.value = index;
+        chl->next = cht[hash];
+        cht[hash] = chl;
       }
 
       *picptr++ = index;
@@ -722,7 +725,7 @@ static chist_vec mediancut( chv, colors, sum, maxval, newcolors )
      ** Find the first splittable box.
      */
     for (bi=0; bv[bi].colors<2 && bi<boxes; bi++) ;
-    if (bi == boxes) break;	/* ran out of colors! */
+    if (bi == boxes) break;        /* ran out of colors! */
 
     indx = bv[bi].index;
     clrs = bv[bi].colors;
@@ -774,14 +777,14 @@ static chist_vec mediancut( chv, colors, sum, maxval, newcolors )
       bl = PPM_LUMIN(p);
 
       if (rl >= gl && rl >= bl)
-	qsort((char*) &(chv[indx]), (size_t) clrs, sizeof(struct chist_item),
-	      redcompare );
+        qsort((char*) &(chv[indx]), (size_t) clrs, sizeof(struct chist_item),
+              redcompare );
       else if (gl >= bl)
-	qsort((char*) &(chv[indx]), (size_t) clrs, sizeof(struct chist_item),
-	      greencompare );
+        qsort((char*) &(chv[indx]), (size_t) clrs, sizeof(struct chist_item),
+              greencompare );
       else 
-	qsort((char*) &(chv[indx]), (size_t) clrs, sizeof(struct chist_item),
-	      bluecompare );
+        qsort((char*) &(chv[indx]), (size_t) clrs, sizeof(struct chist_item),
+              bluecompare );
     }
 
     /*
@@ -831,7 +834,7 @@ static chist_vec mediancut( chv, colors, sum, maxval, newcolors )
       sum += chv[indx + i].value;
     }
 
-    r = r / sum;  if (r>maxval) r = maxval;	/* avoid math errors */
+    r = r / sum;  if (r>maxval) r = maxval;        /* avoid math errors */
     g = g / sum;  if (g>maxval) g = maxval;
     b = b / sum;  if (b>maxval) b = maxval;
 
@@ -897,7 +900,7 @@ static chist_vec
 
 /****************************************************************************/
 static chash_table ppm_computechash(pixels, cols, rows, 
-					    maxcolors, colorsP )
+                                            maxcolors, colorsP )
      pixel** pixels;
      int cols, rows, maxcolors;
      int* colorsP;
@@ -916,22 +919,22 @@ static chash_table ppm_computechash(pixels, cols, rows,
       hash = ppm_hashpixel(*pP);
 
       for (chl = cht[hash]; chl != (chist_list) 0; chl = chl->next)
-	if (PPM_EQUAL(chl->ch.color, *pP)) break;
+        if (PPM_EQUAL(chl->ch.color, *pP)) break;
       
       if (chl != (chist_list) 0) ++(chl->ch.value);
       else {
-	if ((*colorsP)++ > maxcolors) {
-	  ppm_freechash(cht);
-	  return (chash_table) 0;
-	}
-	
-	chl = (chist_list) malloc(sizeof(struct chist_list_item));
-	if (!chl) {fprintf(stderr,"ran out of memory computing hash table");return NULL;};
+        if ((*colorsP)++ > maxcolors) {
+          ppm_freechash(cht);
+          return (chash_table) 0;
+        }
+        
+        chl = (chist_list) malloc(sizeof(struct chist_list_item));
+        if (!chl) {fprintf(stderr,"ran out of memory computing hash table");return NULL;};
 
-	chl->ch.color = *pP;
-	chl->ch.value = 1;
-	chl->next = cht[hash];
-	cht[hash] = chl;
+        chl->ch.color = *pP;
+        chl->ch.value = 1;
+        chl->next = cht[hash];
+        cht[hash] = chl;
       }
     }
   
@@ -1017,15 +1020,15 @@ static void ppm_freechash( cht )
 /* Copyright (C) 1991-1994, Thomas G. Lane.                    */
 /***************************************************************/
 
-#define MAXNUMCOLORS  256	/* maximum size of colormap */
+#define MAXNUMCOLORS  256        /* maximum size of colormap */
 
-#define C0_SCALE 2		/* scale R distances by this much */
-#define C1_SCALE 3		/* scale G distances by this much */
-#define C2_SCALE 1		/* and B by this much */
+#define C0_SCALE 2                /* scale R distances by this much */
+#define C1_SCALE 3                /* scale G distances by this much */
+#define C2_SCALE 1                /* and B by this much */
 
-#define HIST_C0_BITS  5		/* bits of precision in R histogram */
-#define HIST_C1_BITS  6		/* bits of precision in G histogram */
-#define HIST_C2_BITS  5		/* bits of precision in B histogram */
+#define HIST_C0_BITS  5                /* bits of precision in R histogram */
+#define HIST_C1_BITS  6                /* bits of precision in G histogram */
+#define HIST_C2_BITS  5                /* bits of precision in B histogram */
 
 /* Number of elements along histogram axes. */
 #define HIST_C0_ELEMS  (1<<HIST_C0_BITS)
@@ -1041,18 +1044,18 @@ static void ppm_freechash( cht )
 typedef unsigned char JSAMPLE;
 typedef JSAMPLE * JSAMPROW;
 
-typedef u_short histcell;	/* histogram cell; prefer an unsigned type */
+typedef u_short histcell;        /* histogram cell; prefer an unsigned type */
 
-typedef histcell * histptr;	/* for pointers to histogram cells */
+typedef histcell * histptr;        /* for pointers to histogram cells */
 
 typedef histcell hist1d[HIST_C2_ELEMS]; /* typedefs for the histogram array */
 typedef hist1d hist2d[HIST_C1_ELEMS];
 typedef hist2d hist3d[HIST_C0_ELEMS];
 
-typedef short FSERROR;		/* 16 bits should be enough */
-typedef int LOCFSERROR;		/* use 'int' for calculation temps */
+typedef short FSERROR;                /* 16 bits should be enough */
+typedef int LOCFSERROR;                /* use 'int' for calculation temps */
 
-typedef FSERROR *FSERRPTR;	/* pointer to error array */
+typedef FSERROR *FSERRPTR;        /* pointer to error array */
 
 typedef struct {
   /* The bounds of the box (inclusive); expressed as histogram indexes */
@@ -1068,26 +1071,26 @@ typedef box * boxptr;
 
 /* Local state for the IJG quantizer */
 
-static hist2d * sl_histogram;	/* pointer to the 3D histogram array */
-static FSERRPTR sl_fserrors;	/* accumulated-errors array */
-static int * sl_error_limiter;	/* table for clamping the applied error */
-static int sl_on_odd_row;	/* flag to remember which row we are on */
-static JSAMPROW sl_colormap[3];	/* selected colormap */
-static int sl_num_colors;	/* number of selected colors */
+static hist2d * sl_histogram;        /* pointer to the 3D histogram array */
+static FSERRPTR sl_fserrors;        /* accumulated-errors array */
+static int * sl_error_limiter;        /* table for clamping the applied error */
+static int sl_on_odd_row;        /* flag to remember which row we are on */
+static JSAMPROW sl_colormap[3];        /* selected colormap */
+static int sl_num_colors;        /* number of selected colors */
 
 
-static void   slow_fill_histogram PARM((byte*, int));
-static boxptr find_biggest_color_pop PARM((boxptr, int));
-static boxptr find_biggest_volume PARM((boxptr, int));
-static void   update_box PARM((boxptr));
-static int    median_cut PARM((boxptr, int, int));
-static void   compute_color PARM((boxptr, int));
-static void   slow_select_colors PARM((int));
-static int    find_nearby_colors PARM((int, int, int, JSAMPLE []));
-static void   find_best_colors PARM((int,int,int,int, JSAMPLE [], JSAMPLE []));
-static void   fill_inverse_cmap PARM((int, int, int));
-static void   slow_map_pixels PARM((byte*, int, int, byte*));
-static void   init_error_limit PARM((void));
+static void   slow_fill_histogram (byte*, int);
+static boxptr find_biggest_color_pop (boxptr, int);
+static boxptr find_biggest_volume (boxptr, int);
+static void   update_box (boxptr);
+static int    median_cut (boxptr, int, int);
+static void   compute_color (boxptr, int);
+static void   slow_select_colors (int);
+static int    find_nearby_colors (int, int, int, JSAMPLE []);
+static void   find_best_colors (int,int,int,int, JSAMPLE [], JSAMPLE []);
+static void   fill_inverse_cmap (int, int, int);
+static void   slow_map_pixels (byte*, int, int, byte*);
+static void   init_error_limit(void);
 
 
 /* Master control for slow quantizer. */
@@ -1152,8 +1155,8 @@ static void slow_fill_histogram (pic24, numpixels)
   while (numpixels-- > 0) {
     /* get pixel value and index into the histogram */
     histp = & histogram[pic24[0] >> C0_SHIFT]
-		       [pic24[1] >> C1_SHIFT]
-		       [pic24[2] >> C2_SHIFT];
+                       [pic24[1] >> C1_SHIFT]
+                       [pic24[2] >> C2_SHIFT];
     /* increment, check for overflow and undo increment if so. */
     if (++(*histp) <= 0)
       (*histp)--;
@@ -1217,67 +1220,67 @@ static void update_box (boxp)
   if (c0max > c0min)
     for (c0 = c0min; c0 <= c0max; c0++)
       for (c1 = c1min; c1 <= c1max; c1++) {
-	histp = & histogram[c0][c1][c2min];
-	for (c2 = c2min; c2 <= c2max; c2++)
-	  if (*histp++ != 0) {
-	    boxp->c0min = c0min = c0;
-	    goto have_c0min;
-	  }
+        histp = & histogram[c0][c1][c2min];
+        for (c2 = c2min; c2 <= c2max; c2++)
+          if (*histp++ != 0) {
+            boxp->c0min = c0min = c0;
+            goto have_c0min;
+          }
       }
  have_c0min:
   if (c0max > c0min)
     for (c0 = c0max; c0 >= c0min; c0--)
       for (c1 = c1min; c1 <= c1max; c1++) {
-	histp = & histogram[c0][c1][c2min];
-	for (c2 = c2min; c2 <= c2max; c2++)
-	  if (*histp++ != 0) {
-	    boxp->c0max = c0max = c0;
-	    goto have_c0max;             
-	  }
+        histp = & histogram[c0][c1][c2min];
+        for (c2 = c2min; c2 <= c2max; c2++)
+          if (*histp++ != 0) {
+            boxp->c0max = c0max = c0;
+            goto have_c0max;             
+          }
       }
  have_c0max:
   if (c1max > c1min)
     for (c1 = c1min; c1 <= c1max; c1++)
       for (c0 = c0min; c0 <= c0max; c0++) {
-	histp = & histogram[c0][c1][c2min];
-	for (c2 = c2min; c2 <= c2max; c2++)
-	  if (*histp++ != 0) {
-	    boxp->c1min = c1min = c1;
-	    goto have_c1min;
-	  }
+        histp = & histogram[c0][c1][c2min];
+        for (c2 = c2min; c2 <= c2max; c2++)
+          if (*histp++ != 0) {
+            boxp->c1min = c1min = c1;
+            goto have_c1min;
+          }
       }
  have_c1min:
   if (c1max > c1min)
     for (c1 = c1max; c1 >= c1min; c1--)
       for (c0 = c0min; c0 <= c0max; c0++) {
-	histp = & histogram[c0][c1][c2min];
-	for (c2 = c2min; c2 <= c2max; c2++)
-	  if (*histp++ != 0) {
-	    boxp->c1max = c1max = c1;
-	    goto have_c1max;
-	  }
+        histp = & histogram[c0][c1][c2min];
+        for (c2 = c2min; c2 <= c2max; c2++)
+          if (*histp++ != 0) {
+            boxp->c1max = c1max = c1;
+            goto have_c1max;
+          }
       }
  have_c1max:
   if (c2max > c2min)
     for (c2 = c2min; c2 <= c2max; c2++)
       for (c0 = c0min; c0 <= c0max; c0++) {
-	histp = & histogram[c0][c1min][c2];
-	for (c1 = c1min; c1 <= c1max; c1++, histp += HIST_C2_ELEMS)
-	  if (*histp != 0) {
-	    boxp->c2min = c2min = c2;
-	    goto have_c2min;
-	  }
+        histp = & histogram[c0][c1min][c2];
+        for (c1 = c1min; c1 <= c1max; c1++, histp += HIST_C2_ELEMS)
+          if (*histp != 0) {
+            boxp->c2min = c2min = c2;
+            goto have_c2min;
+          }
       }
  have_c2min:
   if (c2max > c2min)
     for (c2 = c2max; c2 >= c2min; c2--)
       for (c0 = c0min; c0 <= c0max; c0++) {
-	histp = & histogram[c0][c1min][c2];
-	for (c1 = c1min; c1 <= c1max; c1++, histp += HIST_C2_ELEMS)
-	  if (*histp != 0) {
-	    boxp->c2max = c2max = c2;
-	    goto have_c2max;
-	  }
+        histp = & histogram[c0][c1min][c2];
+        for (c1 = c1min; c1 <= c1max; c1++, histp += HIST_C2_ELEMS)
+          if (*histp != 0) {
+            boxp->c2max = c2max = c2;
+            goto have_c2max;
+          }
       }
  have_c2max:
 
@@ -1291,9 +1294,9 @@ static void update_box (boxp)
     for (c1 = c1min; c1 <= c1max; c1++) {
       histp = & histogram[c0][c1][c2min];
       for (c2 = c2min; c2 <= c2max; c2++, histp++)
-	if (*histp != 0) {
-	  ccount++;
-	}
+        if (*histp != 0) {
+          ccount++;
+        }
     }
   boxp->colorcount = ccount;
 }
@@ -1316,9 +1319,9 @@ static int median_cut (boxlist, numboxes, desired_colors)
     } else {
       b1 = find_biggest_volume(boxlist, numboxes);
     }
-    if (b1 == NULL)		/* no splittable boxes left! */
+    if (b1 == NULL)                /* no splittable boxes left! */
       break;
-    b2 = &boxlist[numboxes];	/* where new box will go */
+    b2 = &boxlist[numboxes];        /* where new box will go */
     /* Copy the color bounds to the new box. */
     b2->c0max = b1->c0max; b2->c1max = b1->c1max; b2->c2max = b1->c2max;
     b2->c0min = b1->c0min; b2->c1min = b1->c1min; b2->c2min = b1->c2min;
@@ -1380,12 +1383,12 @@ static void compute_color (boxp, icolor)
     for (c1 = c1min; c1 <= c1max; c1++) {
       histp = & histogram[c0][c1][c2min];
       for (c2 = c2min; c2 <= c2max; c2++) {
-	if ((count = *histp++) != 0) {
-	  total += count;
-	  c0total += ((c0 << C0_SHIFT) + ((1<<C0_SHIFT)>>1)) * count;
-	  c1total += ((c1 << C1_SHIFT) + ((1<<C1_SHIFT)>>1)) * count;
-	  c2total += ((c2 << C2_SHIFT) + ((1<<C2_SHIFT)>>1)) * count;
-	}
+        if ((count = *histp++) != 0) {
+          total += count;
+          c0total += ((c0 << C0_SHIFT) + ((1<<C0_SHIFT)>>1)) * count;
+          c1total += ((c1 << C1_SHIFT) + ((1<<C1_SHIFT)>>1)) * count;
+          c2total += ((c2 << C2_SHIFT) + ((1<<C2_SHIFT)>>1)) * count;
+        }
       }
     }
   
@@ -1445,7 +1448,7 @@ static int find_nearby_colors (minc0, minc1, minc2, colorlist)
   int centerc0, centerc1, centerc2;
   int i, x, ncolors;
   INT32 minmaxdist, min_dist, max_dist, tdist;
-  INT32 mindist[MAXNUMCOLORS];	/* min distance to colormap entry i */
+  INT32 mindist[MAXNUMCOLORS];        /* min distance to colormap entry i */
 
   maxc0 = minc0 + ((1 << BOX_C0_SHIFT) - (1 << C0_SHIFT));
   centerc0 = (minc0 + maxc0) >> 1;
@@ -1473,11 +1476,11 @@ static int find_nearby_colors (minc0, minc1, minc2, colorlist)
       /* within cell range so no contribution to min_dist */
       min_dist = 0;
       if (x <= centerc0) {
-	tdist = (x - maxc0) * C0_SCALE;
-	max_dist = tdist*tdist;
+        tdist = (x - maxc0) * C0_SCALE;
+        max_dist = tdist*tdist;
       } else {
-	tdist = (x - minc0) * C0_SCALE;
-	max_dist = tdist*tdist;
+        tdist = (x - minc0) * C0_SCALE;
+        max_dist = tdist*tdist;
       }
     }
 
@@ -1495,11 +1498,11 @@ static int find_nearby_colors (minc0, minc1, minc2, colorlist)
     } else {
       /* within cell range so no contribution to min_dist */
       if (x <= centerc1) {
-	tdist = (x - maxc1) * C1_SCALE;
-	max_dist += tdist*tdist;
+        tdist = (x - maxc1) * C1_SCALE;
+        max_dist += tdist*tdist;
       } else {
-	tdist = (x - minc1) * C1_SCALE;
-	max_dist += tdist*tdist;
+        tdist = (x - minc1) * C1_SCALE;
+        max_dist += tdist*tdist;
       }
     }
 
@@ -1517,15 +1520,15 @@ static int find_nearby_colors (minc0, minc1, minc2, colorlist)
     } else {
       /* within cell range so no contribution to min_dist */
       if (x <= centerc2) {
-	tdist = (x - maxc2) * C2_SCALE;
-	max_dist += tdist*tdist;
+        tdist = (x - maxc2) * C2_SCALE;
+        max_dist += tdist*tdist;
       } else {
-	tdist = (x - minc2) * C2_SCALE;
-	max_dist += tdist*tdist;
+        tdist = (x - minc2) * C2_SCALE;
+        max_dist += tdist*tdist;
       }
     }
 
-    mindist[i] = min_dist;	/* save away the results */
+    mindist[i] = min_dist;        /* save away the results */
     if (max_dist < minmaxdist)
       minmaxdist = max_dist;
   }
@@ -1540,20 +1543,20 @@ static int find_nearby_colors (minc0, minc1, minc2, colorlist)
 
 
 static void find_best_colors (minc0, minc1, minc2, numcolors,
-			      colorlist, bestcolor)
+                              colorlist, bestcolor)
      int minc0, minc1, minc2, numcolors;
      JSAMPLE colorlist[];
      JSAMPLE bestcolor[];
 {
   int ic0, ic1, ic2;
   int i, icolor;
-  register INT32 * bptr;	/* pointer into bestdist[] array */
-  JSAMPLE * cptr;		/* pointer into bestcolor[] array */
-  INT32 dist0, dist1;		/* initial distance values */
-  register INT32 dist2;		/* current distance in inner loop */
-  INT32 xx0, xx1;		/* distance increments */
+  register INT32 * bptr;        /* pointer into bestdist[] array */
+  JSAMPLE * cptr;                /* pointer into bestcolor[] array */
+  INT32 dist0, dist1;                /* initial distance values */
+  register INT32 dist2;                /* current distance in inner loop */
+  INT32 xx0, xx1;                /* distance increments */
   register INT32 xx2;
-  INT32 inc0, inc1, inc2;	/* initial values for increments */
+  INT32 inc0, inc1, inc2;        /* initial values for increments */
   /* This array holds the distance to the nearest-so-far color for each cell */
   INT32 bestdist[BOX_C0_ELEMS * BOX_C1_ELEMS * BOX_C2_ELEMS];
 
@@ -1588,20 +1591,20 @@ static void find_best_colors (minc0, minc1, minc2, numcolors,
       dist1 = dist0;
       xx1 = inc1;
       for (ic1 = BOX_C1_ELEMS-1; ic1 >= 0; ic1--) {
-	dist2 = dist1;
-	xx2 = inc2;
-	for (ic2 = BOX_C2_ELEMS-1; ic2 >= 0; ic2--) {
-	  if (dist2 < *bptr) {
-	    *bptr = dist2;
-	    *cptr = (JSAMPLE) icolor;
-	  }
-	  dist2 += xx2;
-	  xx2 += 2 * STEP_C2 * STEP_C2;
-	  bptr++;
-	  cptr++;
-	}
-	dist1 += xx1;
-	xx1 += 2 * STEP_C1 * STEP_C1;
+        dist2 = dist1;
+        xx2 = inc2;
+        for (ic2 = BOX_C2_ELEMS-1; ic2 >= 0; ic2--) {
+          if (dist2 < *bptr) {
+            *bptr = dist2;
+            *cptr = (JSAMPLE) icolor;
+          }
+          dist2 += xx2;
+          xx2 += 2 * STEP_C2 * STEP_C2;
+          bptr++;
+          cptr++;
+        }
+        dist1 += xx1;
+        xx1 += 2 * STEP_C1 * STEP_C1;
       }
       dist0 += xx0;
       xx0 += 2 * STEP_C0 * STEP_C0;
@@ -1614,13 +1617,13 @@ static void fill_inverse_cmap (c0, c1, c2)
      int c0, c1, c2;
 {
   hist2d * histogram = sl_histogram;
-  int minc0, minc1, minc2;	/* lower left corner of update box */
+  int minc0, minc1, minc2;        /* lower left corner of update box */
   int ic0, ic1, ic2;
-  register JSAMPLE * cptr;	/* pointer into bestcolor[] array */
-  register histptr cachep;	/* pointer into main cache array */
+  register JSAMPLE * cptr;        /* pointer into bestcolor[] array */
+  register histptr cachep;        /* pointer into main cache array */
   /* This array lists the candidate colormap indexes. */
   JSAMPLE colorlist[MAXNUMCOLORS];
-  int numcolors;		/* number of candidate colors */
+  int numcolors;                /* number of candidate colors */
   /* This array holds the actually closest colormap index for each cell. */
   JSAMPLE bestcolor[BOX_C0_ELEMS * BOX_C1_ELEMS * BOX_C2_ELEMS];
 
@@ -1639,7 +1642,7 @@ static void fill_inverse_cmap (c0, c1, c2)
   find_best_colors(minc0, minc1, minc2, numcolors, colorlist, bestcolor);
 
   /* Save the best color numbers (plus 1) in the main cache array */
-  c0 <<= BOX_C0_LOG;		/* convert ID back to base cell indexes */
+  c0 <<= BOX_C0_LOG;                /* convert ID back to base cell indexes */
   c1 <<= BOX_C1_LOG;
   c2 <<= BOX_C2_LOG;
   cptr = bestcolor;
@@ -1647,7 +1650,7 @@ static void fill_inverse_cmap (c0, c1, c2)
     for (ic1 = 0; ic1 < BOX_C1_ELEMS; ic1++) {
       cachep = & histogram[c0+ic0][c1+ic1][c2];
       for (ic2 = 0; ic2 < BOX_C2_ELEMS; ic2++) {
-	*cachep++ = (histcell) (*cptr++ + 1);
+        *cachep++ = (histcell) (*cptr++ + 1);
       }
     }
   }
@@ -1658,15 +1661,15 @@ static void slow_map_pixels (pic24, width, height, pic8)
      byte *pic24, *pic8;
      int   width, height;
 {
-  register LOCFSERROR cur0, cur1, cur2;	/* current error or pixel value */
+  register LOCFSERROR cur0, cur1, cur2;        /* current error or pixel value */
   LOCFSERROR belowerr0, belowerr1, belowerr2; /* error for pixel below cur */
   LOCFSERROR bpreverr0, bpreverr1, bpreverr2; /* error for below/prev col */
-  register FSERRPTR errorptr;	/* => fserrors[] at column before current */
-  JSAMPROW inptr;		/* => current input pixel */
-  JSAMPROW outptr;		/* => current output pixel */
+  register FSERRPTR errorptr;        /* => fserrors[] at column before current */
+  JSAMPROW inptr;                /* => current input pixel */
+  JSAMPROW outptr;                /* => current output pixel */
   histptr cachep;
-  int dir;			/* +1 or -1 depending on direction */
-  int dir3;			/* 3*dir, for advancing inptr & errorptr */
+  int dir;                        /* +1 or -1 depending on direction */
+  int dir3;                        /* 3*dir, for advancing inptr & errorptr */
   int row, col;
   int *error_limit = sl_error_limiter;
   JSAMPROW colormap0 = sl_colormap[0];
@@ -1683,18 +1686,18 @@ static void slow_map_pixels (pic24, width, height, pic8)
     outptr = & pic8[row * width];
     if (sl_on_odd_row) {
       /* work right to left in this row */
-      inptr += (width-1) * 3;	/* so point to rightmost pixel */
+      inptr += (width-1) * 3;        /* so point to rightmost pixel */
       outptr += width-1;
       dir = -1;
       dir3 = -3;
       errorptr = sl_fserrors + (width+1)*3; /* => entry after last column */
-      sl_on_odd_row = FALSE;	/* flip for next time */
+      sl_on_odd_row = FALSE;        /* flip for next time */
     } else {
       /* work left to right in this row */
       dir = 1;
       dir3 = 3;
-      errorptr = sl_fserrors;	/* => entry before first real column */
-      sl_on_odd_row = TRUE;	/* flip for next time */
+      errorptr = sl_fserrors;        /* => entry before first real column */
+      sl_on_odd_row = TRUE;        /* flip for next time */
     }
     /* Preset error values: no error propagated to first pixel from left */
     cur0 = cur1 = cur2 = 0;
@@ -1720,14 +1723,14 @@ static void slow_map_pixels (pic24, width, height, pic8)
       /* If we have not seen this color before, find nearest colormap */
       /* entry and update the cache */
       if (*cachep == 0)
-	fill_inverse_cmap(cur0>>C0_SHIFT, cur1>>C1_SHIFT, cur2>>C2_SHIFT);
+        fill_inverse_cmap(cur0>>C0_SHIFT, cur1>>C1_SHIFT, cur2>>C2_SHIFT);
       /* Now emit the colormap index for this cell */
       { register int pixcode = *cachep - 1;
-	*outptr = (JSAMPLE) pixcode;
-	/* Compute representation error for this pixel */
-	cur0 -= (int) colormap0[pixcode];
-	cur1 -= (int) colormap1[pixcode];
-	cur2 -= (int) colormap2[pixcode];
+        *outptr = (JSAMPLE) pixcode;
+        /* Compute representation error for this pixel */
+        cur0 -= (int) colormap0[pixcode];
+        cur1 -= (int) colormap1[pixcode];
+        cur2 -= (int) colormap2[pixcode];
       }
       /* Compute error fractions to be propagated to adjacent pixels.
        * Add these into the running sums, and simultaneously shift the
@@ -1735,38 +1738,38 @@ static void slow_map_pixels (pic24, width, height, pic8)
        */
       { register LOCFSERROR bnexterr, delta;
 
-	bnexterr = cur0;	/* Process component 0 */
-	delta = cur0 * 2;
-	cur0 += delta;		/* form error * 3 */
-	errorptr[0] = (FSERROR) (bpreverr0 + cur0);
-	cur0 += delta;		/* form error * 5 */
-	bpreverr0 = belowerr0 + cur0;
-	belowerr0 = bnexterr;
-	cur0 += delta;		/* form error * 7 */
-	bnexterr = cur1;	/* Process component 1 */
-	delta = cur1 * 2;
-	cur1 += delta;		/* form error * 3 */
-	errorptr[1] = (FSERROR) (bpreverr1 + cur1);
-	cur1 += delta;		/* form error * 5 */
-	bpreverr1 = belowerr1 + cur1;
-	belowerr1 = bnexterr;
-	cur1 += delta;		/* form error * 7 */
-	bnexterr = cur2;	/* Process component 2 */
-	delta = cur2 * 2;
-	cur2 += delta;		/* form error * 3 */
-	errorptr[2] = (FSERROR) (bpreverr2 + cur2);
-	cur2 += delta;		/* form error * 5 */
-	bpreverr2 = belowerr2 + cur2;
-	belowerr2 = bnexterr;
-	cur2 += delta;		/* form error * 7 */
+        bnexterr = cur0;        /* Process component 0 */
+        delta = cur0 * 2;
+        cur0 += delta;                /* form error * 3 */
+        errorptr[0] = (FSERROR) (bpreverr0 + cur0);
+        cur0 += delta;                /* form error * 5 */
+        bpreverr0 = belowerr0 + cur0;
+        belowerr0 = bnexterr;
+        cur0 += delta;                /* form error * 7 */
+        bnexterr = cur1;        /* Process component 1 */
+        delta = cur1 * 2;
+        cur1 += delta;                /* form error * 3 */
+        errorptr[1] = (FSERROR) (bpreverr1 + cur1);
+        cur1 += delta;                /* form error * 5 */
+        bpreverr1 = belowerr1 + cur1;
+        belowerr1 = bnexterr;
+        cur1 += delta;                /* form error * 7 */
+        bnexterr = cur2;        /* Process component 2 */
+        delta = cur2 * 2;
+        cur2 += delta;                /* form error * 3 */
+        errorptr[2] = (FSERROR) (bpreverr2 + cur2);
+        cur2 += delta;                /* form error * 5 */
+        bpreverr2 = belowerr2 + cur2;
+        belowerr2 = bnexterr;
+        cur2 += delta;                /* form error * 7 */
       }
       /* At this point curN contains the 7/16 error value to be propagated
        * to the next pixel on the current line, and all the errors for the
        * next line have been shifted over.  We are therefore ready to move on.
        */
-      inptr += dir3;		/* Advance pixel pointers to next column */
+      inptr += dir3;                /* Advance pixel pointers to next column */
       outptr += dir;
-      errorptr += dir3;		/* advance errorptr to current column */
+      errorptr += dir3;                /* advance errorptr to current column */
     }
     /* Post-loop cleanup: we must unload the final error values into the
      * final fserrors[] entry.  Note we need not unload belowerrN because
@@ -1789,7 +1792,7 @@ static void init_error_limit ()
   table = (int *) malloc((size_t) ((255*2+1) * sizeof(int)));
   if (! table) return;
 
-  table += 255;		/* so can index -255 .. +255 */
+  table += 255;                /* so can index -255 .. +255 */
   sl_error_limiter = table;
 
 #define STEPSIZE ((255+1)/16)
