@@ -2,7 +2,7 @@
 #define ACCEL_H
 #include <stdlib.h>
 extern int depth,bdep,b_pad,translation;
-extern unsigned int rmask,gmask,bmask,rsh,bsh,gsh,rind,bind,gind;
+extern unsigned int rmask,gmask,bmask,rsh,bsh,gsh;
 extern unsigned int red_rsh,green_rsh,blue_rsh,red_lsh,green_lsh,blue_lsh;
 #ifdef __cplusplus
 extern "C" char *im_alloc_true(int l,int h);
