@@ -1,6 +1,6 @@
 /****************************************************************************
 *  Copyright (C) 1996-98 by Leo Khramov
-*  email:     leo@unix1.jinr.dubna.su
+*  email:     leo@xnc.dubna.su
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ int fromMem=0;
 Colormap defc;                                                                          
 PICINFO im;
 char *trans;
-uint rmask,gmask,bmask,rsh,bsh,gsh,rind,bind,gind;
+uint rmask,gmask,bmask,rsh,bsh,gsh;
 uint red_rsh,green_rsh,blue_rsh,red_lsh,green_lsh,blue_lsh;
 XColor *XColorTable;
 Colormap lcmp;
@@ -40,6 +40,8 @@ void im_256truecoding(char**,int);
 void im_256nocoding(char**,int);
 void im_256256coding(char**,int);
 
+unsigned long *global_pal=NULL;
+
 #ifdef PSEUDOCOLOR                     
 unsigned long XPixelTable[256];
 unsigned long Xfreepix[256];
@@ -56,6 +58,7 @@ int im_getpixels(unsigned long* pt)
  for(int i=0;i<ptnum;i++)
   pt[i]=Xfreepix[i];
 #endif
+ return 0;
 }
 
 void im_clear_pic()
@@ -136,12 +139,14 @@ void im_union_colors()
 void im_add_cmp_entry(unsigned long ent)
 {
   Xfreepix[ptnum++]=ent;
+  if(global_pal)
+          global_pal[ptnum-1]=ent;
 }
 
 void im_alloc_closest_cmp(Colormap XColorMap,int ColorMapSize=256)
 {
     int i, j, Index = 0, Count = 0, XNumOfColors;
-    unsigned long D, Distance, AvgDistance = 0, Red, Green, Blue;
+    unsigned long D, Distance, Red, Green, Blue;
     int Failed = False;
     XColor *XOldColorTable;
     ptnum=0;
@@ -210,7 +215,7 @@ void im_alloc_closest_cmp(Colormap XColorMap,int ColorMapSize=256)
 
 void im_alloccmp(Colormap XColorMap,int ColorMapSize=256)
 {
-    int Strip, Msk, i, j;
+    int Strip, Msk, i;
     ptnum=0;
     im_alloc_closest_cmp(XColorMap,ColorMapSize);
     return;
@@ -227,7 +232,7 @@ void im_alloccmp(Colormap XColorMap,int ColorMapSize=256)
             if (XAllocColor(disp,XColorMap , &XColorTable[i]))
   {
                 XPixelTable[i] = XColorTable[i].pixel;
-  im_add_cmp_entry(XPixelTable[i]);
+                im_add_cmp_entry(XPixelTable[i]);
   }
             else
                 break;
@@ -304,6 +309,113 @@ void im_set_coding()
  translation=1;
 }
 
+long cmap_distance[256];
+int XCmapNumColors;
+XColor *XCmapColorTable=NULL;
+Colormap XCmapCmap;
+
+long im_calc_weight(unsigned short red,
+                               unsigned short green,
+                               unsigned short blue)
+{
+  double r=(double)red;
+  double g=(double)green;
+  double b=(double)blue;
+  return (long)sqrt(r*r+g*g+b*b);
+}
+
+void im_init_cmap(Colormap XColorMap)
+{
+  
+    int i, XNumOfColors;
+    int screen=DefaultScreen(disp);
+    
+        depth=DefaultDepth(disp,screen);
+        vis=DefaultVisual(disp,screen);
+        defc=DefaultColormap(disp,screen);
+        vclass=vis->c_class;
+        XNumOfColors = DisplayCells(disp,DefaultScreen(disp));
+        if(XCmapColorTable == NULL)
+          XCmapColorTable = (XColor *) malloc(sizeof(XColor) * XNumOfColors);
+        for (i = 0; i < XNumOfColors; i++) 
+                XCmapColorTable[i].pixel = i;
+        XQueryColors(disp, XColorMap, XCmapColorTable, XNumOfColors);
+        
+        for(i=0;i< XNumOfColors;i++)
+        {
+             cmap_distance[i]=im_calc_weight(XCmapColorTable[i].red,
+                                            XCmapColorTable[i].green,
+                                            XCmapColorTable[i].blue);
+        }
+        XCmapNumColors=XNumOfColors;
+        XCmapCmap=XColorMap;
+}
+
+int im_find_closest_color(XColor* orig, XColor* tocol)
+{
+  unsigned long weight,distance, Red, Green, Blue, D;
+  int idx=0,i;
+  if(vclass==TrueColor)
+  {
+     *tocol=*orig;
+     return 0;
+  }
+  Red=orig->red;
+  Green=orig->green;
+  Blue=orig->blue;
+  distance=0xffffffff;
+  for(i=0;i<XCmapNumColors;i++)
+  {
+      if ((D = ABS(Red - XCmapColorTable[i].red) +
+           ABS(Green - XCmapColorTable[i].green) +
+           ABS(Blue - XCmapColorTable[i].blue)) < distance) 
+              {
+                  distance = D;
+                  idx = i;
+              }
+  }
+  *tocol=XCmapColorTable[idx];
+  tocol->flags = DoGreen | DoRed | DoBlue;
+  return 1;
+}
+
+int im_find_closest_color2(XColor* orig, XColor* tocol)
+{
+  long weight,distance;
+  int idx=0,i;
+  if(vclass==TrueColor)
+  {
+     *tocol=*orig;
+     return 0;
+  }
+  weight=im_calc_weight(orig->red, orig->green, orig->blue);
+  distance=ABS(cmap_distance[idx]-weight);
+  for(i=1;i<XCmapNumColors;i++)
+    if(distance>ABS(cmap_distance[i]-weight))
+    {
+            idx=i;
+            distance=ABS(cmap_distance[i]-weight);
+    }
+  *tocol=XCmapColorTable[idx];
+  tocol->flags = DoGreen | DoRed | DoBlue;
+  return 1;
+}
+
+Status im_AllocColor(Display* d, Colormap cmap, XColor *cl)
+{
+    XColor cl2;
+    Status st;
+    if((st=XAllocColor(disp, cmap, cl))!=0)
+       return st; 
+    if(cmap!=XCmapCmap || XCmapColorTable==NULL)
+      im_init_cmap(cmap);
+    im_find_closest_color2(cl, &cl2);
+    *cl=cl2;
+    return XAllocColor(disp, cmap, cl);
+}
+
+Status (*pim_AllocColor)(Display*, Colormap, XColor*)=im_AllocColor;
+
 void init_imagengine()
 {
  XImage* xim;
@@ -361,6 +473,7 @@ void init_imagengine()
     translation=1;
     Init24to8();
     XColorTable=new XColor[256];
+    im_init_cmap(defc);
     im_coding256=im_256256coding;
     im_coding=im_truenocoding;
     fprintf(stderr,"*Visual:  PseudoColor          *\n");
@@ -417,6 +530,9 @@ int autodetect(char *f)
            buf[4]==0 && buf[5]==0 &&
            buf[6]==0 && buf[7]==0)  return F_TARGA;
 #endif
+#ifdef PNG_SUPPORT
+ else if (strncmp((char*)buf+1,"PNG", (size_t) 3)==0)  return F_PNG;
+#endif
 
  else if(buf[0]==0xff && buf[1]==0xd8 && buf[2]==0xff) return F_JPEG;
 
@@ -446,7 +562,8 @@ void im_init_translation()
     {
      cmp=im_choose_cmp();
      im_alloccmp(cmp);
-     return;};
+     return;
+    };
 #endif
    col.flags=DoRed | DoGreen | DoBlue;
    for(i=0;i<256;i++)
@@ -456,6 +573,8 @@ void im_init_translation()
      col.green=(unsigned short)(im.pal[i3+1])<<8;
      col.blue=(unsigned short)(im.pal[i3+2])<<8;
      XAllocColor(disp,defc,&col);
+     if(global_pal)
+       global_pal[i]=col.pixel;
      for(j=bdep-1;j>=0;j--)
       {
        trans[i2-j-1]=(char)((col.pixel>>(j<<3))& 0xff);
@@ -467,11 +586,10 @@ void im_init_translation()
 
 XImage *LoadXImage(char *file,int cmptype,int type)
 {
- int i,j,l,ii,lw,x,y;
- ulong mask,pixel;
- int ir,ib,ig;
+ int i,j,l,lw,x,y;
+ ulong mask;
  char *imdata,*imdat;
- int ind,delta;
+ int ind;
  XImage *xim;
  ::cmptype=cmptype;
  if(vclass==DirectColor) return NULL;
@@ -505,6 +623,14 @@ XImage *LoadXImage(char *file,int cmptype,int type)
          if(LoadTIFF(file,&im)) break;else {fprintf(stderr,"Image Engine: LoadTiff\n");return NULL;};
 #else
          return NULL;
+#endif
+    case F_PNG:
+#ifdef PNG_SUPPORT
+        im_clear_pic();
+         translation= 0;
+         if(LoadPNG(file,&im)) break;else {fprintf(stderr,"Image Engine: LoadPNG\n");return NULL;};
+#else
+         return NULL;
 #endif
     case F_PCX:
 #ifdef PCXSUPPORT
@@ -637,9 +763,8 @@ XImage *LoadXImage(char *file,int cmptype,int type)
 
 XImage* encoding256(PICINFO& im,int ncol)
 {
- int i,j,l,ii,k,lw;
- ulong mask,pixel;
- int ir,ib,ig;
+ int i,j,l,k,lw;
+ ulong mask;
  char *trans;
  char *imdata;
  int ind,delta;
@@ -747,5 +872,14 @@ Pixmap LoadPixmapFromMem(char *fname,int type,int& l,int& h,int cmptype,int siz)
    }
  return 0;
 }  
- 
+
+void im_populate_pallete(unsigned long* pal)
+{
+        global_pal=pal;
+}
+
+void im_clear_global_pal()
+{
+        global_pal=NULL;
+}  
                                                                   
