@@ -1,7 +1,7 @@
 /****************************************************************************
 *  Copyright (C) 1996 by Leo Khramov
-*  email:     leo@pop.convey.ru
-*  Fido:      2:5030/627.15
+*  email:     leo@xnc.dubna.su
+*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
@@ -16,8 +16,10 @@
 #include "../scroll.h"
 #include <X11/keysym.h>
 #include <ctype.h>
-extern char rustbl[];
-extern char wrustbl[];
+extern unsigned char rustbl[];
+extern unsigned char wrustbl[];
+extern unsigned char dostbl[];
+extern unsigned char wintbl[];
 
 Atom wmDeleteWindow;
 
@@ -81,6 +83,10 @@ void saveas(char *head,char *mes,Viewer* ivw,int inum)
  vdok=new KEY(40,-20,80,25,"OK",1,vok);
  vdcan=new KEY(-40,-20,80,25,"Cancel",2,vcan);
  vdin=new Input(10,50,280,1,vok);
+ if(inum==1)
+         vdin->set_histid("FIND");
+ else
+         vdin->set_histid("SAVE");
  vdin->set_escapefunc(vcan);
  vdok->set_escapefunc(vcan);
  vdt1=new Text(10,40,mes,5);
@@ -164,7 +170,7 @@ void Viewer::init(Window ipar)
  if(l<tw+40) l=tw+40;
  ty=(21+fixfontstr->max_bounds.ascent-fixfontstr->max_bounds.descent)/2;
  vish=(h-V_FRAME)/ty;
- tx=fixfontstr->max_bounds.rbearing-fixfontstr->min_bounds.lbearing;
+ tx=XTextWidth(fixfontstr,"MMMMMMMMMM",10)/10;
  visl=(l-10)/tx;
  n=(visl-8)/4;
  prflg=row=0;
@@ -185,7 +191,7 @@ void Viewer::reconfigure(int il,int ih)
  XSetClipRectangles(disp,gct,5,24,&rec,1,YXSorted);
  ty=(21+fixfontstr->max_bounds.ascent-fixfontstr->max_bounds.descent)/2;
  vish=(h-V_FRAME)/ty;
- tx=fixfontstr->max_bounds.rbearing-fixfontstr->min_bounds.lbearing;
+ tx=XTextWidth(fixfontstr,"MMMMMMMMMM",10)/10;
  visl=(l-10)/tx;
  n=(visl-8)/4;
  XClearWindow(disp,w);
@@ -224,7 +230,7 @@ void Viewer::showhexfile()
  XSetFont(disp,gct,fixfontstr->fid);
  ty=(fixfontstr->max_bounds.ascent+fixfontstr->max_bounds.descent);
  vish=(h-V_FRAME)/ty;
- tx=fixfontstr->max_bounds.rbearing-fixfontstr->min_bounds.lbearing;
+ tx=XTextWidth(fixfontstr,"MMMMMMMMMM",10)/10;
  visl=(l-10)/tx;
  n=(visl-8)/4;
  nn=n*3+8;
@@ -393,8 +399,8 @@ void Viewer::click()
         if(endfunc) endfunc(this);break;
      case XK_F2: saveas("Save file","Save as:",this,0);break;
      case XK_F6: if(swfunc) swfunc(this);break;
-     case XK_F11: if(koi==0) rusconvert();break;
-     case XK_F12: if(koi==0) rusconvert();break;
+     case XK_F11: rusconvert();break;
+     case XK_F12: wrusconvert();break;
      case XK_F7:
      case XK_slash:
      case XK_Find:  saveas("Find","Find text:",this,1);break;
@@ -414,10 +420,17 @@ void Viewer::click()
 void Viewer::hex_asc()
 {
   int j;
-  hex^=1;if(hex)
-  {base=base-(base%n);cbase=base;showhexfile();
-     showcurs();info();scr->setrange(0,(node->size+n-1)/n);scr->val=base/n;scr->setpages((node->size+n-1)/n/vish);
-     scr->expose();}
+  hex^=1;
+  if(hex)
+  {
+     base=base-(base%n);cbase=base;
+     showhexfile();
+     showcurs();info();
+     scr->setrange(0,(node->size+n-1)/n);
+     scr->val=base/n;
+     scr->setpages((node->size+n-1)/n/vish);
+     scr->expose();
+  }
   else {
   XClearArea(disp,w,5,24,l-10,h-V_FRAME,False);
   while(base>-1 && buf[base]!=0xa) base--;base++;
@@ -472,13 +485,18 @@ void Viewer::insert(KeySym *ks)
  char *tbl="0123456789ABCDEF";
  XComposeStatus cs;
  char sym[4];
- char str[96];
+ char str[396];
  int bs,ii,k,j;
  int i,bb=cbase;
  XLookupString(&ev.xkey,sym,4,ks,&cs);
  showcurs(0);
  if(tab==2)
  {
+ if(sym[0]<32)
+ {
+         showcurs();
+         return;
+ }
  buf[cbase]=sym[0];
  nn=n*3+8;
  sl=n*4+8;
@@ -654,7 +672,7 @@ void Viewer::info()
  XFillRectangle(disp,w,gcw,2,2,l-4,18);
  XSetForeground(disp,gcw,cols[0]);
  nl=strlen(node->name);
- tx=fixfontstr->max_bounds.rbearing-fixfontstr->min_bounds.lbearing;
+ tx=XTextWidth(fixfontstr,"M",1);
  visl=(l-10)/tx;
  k=visl/3;
  if(nl>k) nl=k-1;
@@ -754,7 +772,8 @@ void Viewer::save()
  FILE* fp=fopen(vdbuf,"w");
  if(fp!=NULL)
  {
-  if(fwrite(buf,node->size,1,fp)!=1) fprintf(stderr,"Errorno:%d\n",errno);
+  if(fwrite(buf,node->size,1,fp)!=1) 
+        fprintf(stderr,"Error:%d\n",strerror(errno));
   fclose(fp);
 //  delete node->name;
 //  node->name=new char[strlen(vdbuf)+1];
@@ -791,24 +810,81 @@ void Viewer::linenum()
    info();
   } else vmes("Error","Wrong line number!!!",this);
 }
-   
+
+void printhbuf(unsigned char *buf, int size)
+{
+  int i;
+  for(i=0;i<size;i++)
+    printf("%02X ",buf[i]);
+  printf("\n");
+}
+
 void Viewer::rusconvert()
 {
  int i;
- for(i=0;i<node->size;i++)
-  buf[i]=rustbl[buf[i]];
- if(hex) {showhexfile();showcurs();}
+ unsigned char* bu=(unsigned char*)buf;
+ if(rusconv_state==KOI8)
+ {
+   for(i=0;i<node->size;i++)
+     bu[i]=rustbl[bu[i]];
+   rusconv_state=CP866;
+   xncdprintf(("CP866->KOI8\n"));
+ } else
+   if(rusconv_state==CP866)
+   {
+     for(i=0;i<node->size;i++)
+       bu[i]=dostbl[bu[i]];
+     rusconv_state=KOI8;
+     xncdprintf(("KOI8->CP866\n"));
+   } else
+   {
+     for(i=0;i<node->size;i++)
+       bu[i]=wintbl[bu[i]];
+     rusconv_state=KOI8;
+     xncdprintf(("KOI8->WIN1251\n"));
+   }
+ if(hex) 
+ {
+   showhexfile();
+   showcurs();
+ }
  else showasc();
+
+ printhbuf(bu,node->size);
  koi=1;
 }
 
 void Viewer::wrusconvert()
 {
  int i;
- for(i=0;i<node->size;i++)
-  buf[i]=wrustbl[buf[i]];  
- if(hex) {showhexfile();showcurs();}
+ unsigned char* bu=(unsigned char*)buf;
+ if(rusconv_state==KOI8)
+ {
+   for(i=0;i<node->size;i++)
+     bu[i]=wrustbl[bu[i]];
+   rusconv_state=WIN1251;
+   xncdprintf(("WIN1251->KOI8\n"));
+ } else
+   if(rusconv_state==CP866)
+   {
+     for(i=0;i<node->size;i++)
+       bu[i]=dostbl[bu[i]];
+     rusconv_state=KOI8;
+     xncdprintf(("KOI8->CP866\n"));
+   } else
+   {
+     for(i=0;i<node->size;i++)
+       bu[i]=wintbl[bu[i]];
+     rusconv_state=KOI8;
+     xncdprintf(("KOI8->WIN1251\n"));
+   }
+ if(hex) 
+ {
+   showhexfile();
+   showcurs();
+ }
  else showasc();
+ printhbuf(bu,node->size);
  koi=1;
 }
 
