@@ -1,6 +1,6 @@
 /****************************************************************************
 *  Copyright (C) 1996-98 by Leo Khramov
-*  email:   leo@unix1.jinr.dubna.su
+*  email:   leo@xnc.dubna.su
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -12,143 +12,108 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
  ****************************************************************************/
+/* $Id: main.cxx,v 1.12 2000/12/26 12:40:27 leo Exp $ */
+
 #include "panel.h"
 #include "scroll.h"
 #include "ver.h"
 #include "build.h"
 #include "comp.h"
 #include "image/image.h"
-#include "au/key.h"
 #include "bookmark.h"
+#include "au/au.h"
 #include "au/au_sup.h"
+#include "au/key.h"
 #include "ftpfs.h"
 #include "internals.h"
 #include "query_windows.h"
 #include "ftpvisuals.h"
 #include "xncversion.h"
+#include "history.h"
+#include "ftpcfg.h"
+#include "c_externs.h"
+#include "internals.h"
+#include "pluginman.h"
+#include "ives/ivesclient.h"
 
 char   ver[] = "X Northern Captain "XNCVERSION;
 
-extern "C" void clean_exit();
-extern Window main_win;
 
-extern char *syspath;
-extern Atom wmDeleteWindow;
+extern Window main_win;
+extern Atom   wmDeleteWindow;
+extern void   init_chown_dialog(FList *);
+extern void   dfs_info(int);
+extern void   free_info(int);
+extern void   find_panel(int);
+extern int    term_sticky;
+extern int    dont_ask;        //Placed in panel.cxx
+extern int    layout;
+extern Viewer vw1;
+extern Editor ew1;
+extern void   menupanel(int (*)(int, char *));
+extern int    panexec2(int, char *);
+extern void   newtextfile(char *, Lister *, int);
+extern int    just_at_startup;
+extern int    focus_fl;
+extern char   shdir[];
+extern AFS    afstmp;
+
+
+
 char   dispstr[40] = "";
 int    main_show = 1;
 int    resize_done = 0;
-int    mainuid, maingid;
-extern int term_sticky;
 BookMark *bmark;
 Switcher *fsw1;
 FtpVisual *fvis;
 
-////////////////////////////////////Shared Memory routines////////////////////////
-#include <sys/ipc.h>
-#include <sys/shm.h>
-#include <signal.h>
+int no_ives=NO;
 
-char   ivesrun[40];
 
-#include "ives/ivestruct.h"
+////////////////////////////////////IVES routines////////////////////////
+IVES_client *iclient;
 
-IVESid *sm;
-char  *smem;
-char  *umem;
-int    pid, sid;
+char ivesrun[256];
 
-int    ives_initshare()
-{
-  int    key = 0x1976;
-  pid = getpid();
-  key += geteuid();
-  sid = shmget(key, 1024, 0666 | IPC_CREAT | IPC_EXCL);
-  while (sid == -1)
-    {
-      sid = shmget(key, 1024, 0666 | IPC_CREAT);
-      if (sid != -1)
-        {
-          smem = shmat(sid, NULL, 0);
-          sm = (IVESid *) smem;
-          if (strcmp("IVES", sm->name) == 0)
-            {
-              umem = smem + sizeof(IVESid);
-              fprintf(stderr, "OK\n");
-              return 0;
-            }
-          else
-            {
-              shmdt(smem);
-              key++;
-              sid = shmget(key, 1024, 0666 | IPC_CREAT | IPC_EXCL);
-            };
-        }
-      else
-        key++;
-    }
-  shmdt(smem);
-  shmctl(sid, IPC_RMID, NULL);
-  fprintf(stderr, "failed\n");
-  fprintf(stderr, "Runing IVES!\n");
-  psystem(ivesrun);
-  sleep(5);
-  return 1;
-}
-
-void   ives_deinit()
-{
-  shmid_ds shm_info;
-  if (strcmp(viewname, "internal") == 0 || strcmp(editname, "internal") == 0)
-    {
-      shmdt(smem);
-      shmctl(sid, IPC_STAT, &shm_info);
-      if (shm_info.shm_nattch == 0)
-        shmctl(sid, IPC_RMID, NULL);
-    }
-}
-
-int    is_ives(IVESid * s)
-{
-  int    uid = geteuid(), rr = 0, i;
-  for (i = 0; i < s->maxent; i++)
-    if (s->ivespid[i][1] == uid)
-      if (((rr = kill(s->ivespid[i][0], SIGUSR2)) == 0) || (rr == -1 && errno != ESRCH))
-        return s->ivespid[i][0];
-  return -1;
-}
-
-extern "C" void psystem(char *);
 void   sendtoives(char *name, int type, int ret = 0)
 {
-  int    ipid;
-  while ((ipid = is_ives(sm)) == -1)
+  char umem[L_MAXPATH];
+  Window focus_to;
+  int    ipid,i=0;
+  if(no_ives)
+  {
+          simple_mes("Error connecting to IVES","Editor and/or Viewer not available! Use 'xncsetup' for correct");
+          return;
+  }
+  while (iclient->Init()==0)
     {
       XBell(disp, 0);
       show_mes("Loading IVES", "   Please wait...");
       psystem(ivesrun);
       sleep(1);
       hide_mes();
+      i++;
+      if(i>3)
+      {
+              simple_mes("Error", "IVE System not available!");
+              return;
+      }
     };
-  while (sm->ready != 1)
-    sleep(1);
-  sm->ready = 0;
-  sm->type = type;
-  sm->autopid = getpid();
-  sm->retval = ret;
   if (main_show)
-    sm->focus_to = Main;
+    focus_to = Main;
   else
-    sm->focus_to = 0;
+    focus_to = 0;
+
+
   if (name[0] != '/')
     {
-      getcwd(umem, 255);
+      getcwd(umem, 1024);
       strcat(umem, "/");
       strcat(umem, name);
     }
   else
     strcpy(umem, name);
-  if (kill(ipid, SIGUSR1) == -1)
-    fprintf(stderr, "XNC(%d): SIGUSR2 to IVES failed\n", getpid());
+  iclient->send_data(DefaultRootWindow(disp),IVES_data(Main,type,focus_to,umem,ret));
 }
 
 
@@ -157,7 +122,7 @@ void   defret()
   if (panel->lay == 0)
     panel->panel2->reread();
   panel->reread();
-// XSetInputFocus(disp,panel->w,RevertToNone,CurrentTime);
+// guiSetInputFocus(disp,panel->w,RevertToNone,CurrentTime);
 }
 
 void   manret()
@@ -188,16 +153,9 @@ void   (*funcs[]) () =
 };
 
 
-void   sigusr(int)
+void   ives_retval(int ret)
 {
-  int    ret;
-  if (sm->ready != 1)
-    {
-      ret = sm->retval;
-      sm->ready = 1;
-      funcs[ret] ();
-    }
-  signal(SIGUSR1, sigusr);
+  funcs[ret]();
 }
 
 void   viewhighlight(char *name)
@@ -205,10 +163,6 @@ void   viewhighlight(char *name)
   sendtoives(name, 3, 1);
 }
 
-extern void init_chown_dialog(FList *);
-void   dfs_info(int);
-void   free_info(int);
-void   find_panel(int);
 void   p_info()
 {
   panel->ps_info();
@@ -229,7 +183,7 @@ void   findfunc()
 {
   find_panel(centerx * 2 - 40);
 };
-extern int layout;
+
 void   donefunc();
 void   viewfunc();
 void   editfunc();
@@ -239,6 +193,8 @@ void   delfunc();
 void   mkdirfunc();
 void   remntfunc();
 void   manfunc();
+void   revfunc1();
+void   revfunc2();
 void   p1col1();
 void   p1col2();
 void   p1col3();
@@ -255,25 +211,30 @@ void   p1time();
 void   p2time();
 void   p1size();
 void   p2size();
+void   p1unsort();
+void   p2unsort();
 void   p1brief();
 void   p2brief();
 void   p1full();
 void   p2full();
+void   configure_func() {show_config_win();};
 void   edit_ext();
 void   edit_menu();
 void   attrfunc();
 void   menu_func();
-void   try_clean_afs_cache();
 void   show_hidden_files();
-extern Viewer vw1;
-extern Editor ew1;
+void   try_clean_afs_cache();
+void   compare_dirs() {panel->compare_panels();panel->panel2->compare_panels();};
+void   use_sizes() {compare_by_size^=1;};
+void   use_times() {compare_by_time^=1;};
 MenuBar *emn;
 MenuBar *ftpmn;
 FList *node;
 
-char   so1[11][25] =
+char   so1[13][25] =
 {"PBrief", "pFull ", "pOne column", "PTwo columns", "pThree columns",
- "pFour columns ", "pSort by Names", "PSort by Extensions", "pSort by Size", "pSort by Time ", "FQuit"};
+ "pFour columns ", "pSort by Names", "PSort by Extensions", 
+ "pSort by Size", "pSort by Time", "pUnsorted ", "sReverse sort ", "FQuit"};
 
 MenuItem subm1[] =
 {
@@ -287,19 +248,21 @@ MenuItem subm1[] =
   so1[7], 5, p1ext, NULL,
   so1[8], 5, p1size, NULL,
   so1[9], 5, p1time, NULL,
-  so1[10], 2, donefunc, NULL
+  so1[10], 5, p1unsort, NULL,
+  so1[11], 5, revfunc1, NULL,
+  so1[12], 2, donefunc, NULL
 };
-char   hidechr[] = "SShow hidden files";
 MenuItem optmenu[] =
 {
   "FEdit menu file", 5, edit_menu, NULL,
   "FEdit extension file ", 5, edit_ext, NULL,
   "FClean AFS cache ", 5, try_clean_afs_cache, NULL,
-  hidechr, 5, show_hidden_files, NULL
+  "FConfiguration", 1, configure_func, NULL,
 };
-char   so2[10][25] =
+char   so2[12][25] =
 {"PBrief", "pFull ", "pOne column", "PTwo columns", "pThree columns",
- "pFour columns ", "pSort by Names", "PSort by Extensions", "pSort by Size", "pSort by Time"};
+ "pFour columns ", "pSort by Names", "PSort by Extensions", 
+ "pSort by Size", "pSort by Time", "pUnsorted ", "sReverse sort"};
 MenuItem subm2[] =
 {
   so2[0], 5, p2brief, NULL,
@@ -312,7 +275,12 @@ MenuItem subm2[] =
   so2[7], 5, p2ext, NULL,
   so2[8], 5, p2size, NULL,
   so2[9], 5, p2time, NULL,
+  so2[10], 5, p2unsort, NULL,
+  so2[11], 5, revfunc2, NULL
 };
+
+char so3[2][25]={"SCompare by sizes", "sCompare by times"};
+
 MenuItem submnu2[] =
 {
   "FRemount current directory", 5, remntfunc, NULL,
@@ -329,22 +297,26 @@ MenuItem submnu2[] =
   "FQuick ScanDir Info", 5, qview, NULL,
   "FProcesses Info", 5, p_info, NULL,
   "FMemory Info", 5, m_info, NULL,
-  "FDisk Info", 5, d_info, NULL
+  "FDisk Info", 5, d_info, NULL,
+  "FStat Info ", 5, toggle_inodewin, NULL,
+  "FCompare directories", 5, compare_dirs, NULL,
+  so3[0], 5, use_sizes, NULL,
+  so3[1], 5, use_times, NULL
 };
 
-Menu   submenu1(subm1, 11);
-Menu   submenu2(subm2, 10);
-Menu   submenu3(submnu2, 15);
-Menu   submenu4(optmenu, 4);
+Menu   *submenu1=0;
+Menu   *submenu2=0;
+Menu   *submenu3=0;
+Menu   *submenu4=0;
 MenuItem menu[] =
-{"Left", 1, NULL, &submenu1,
- "Commands", 1, NULL, &submenu3,
- "Options", 1, NULL, &submenu4,
- "-Right", 3, NULL, &submenu2,
+{"Left", 1, NULL, submenu1,
+ "Commands", 1, NULL, submenu3,
+ "Options", 1, NULL, submenu4,
+ "-Right", 3, NULL, submenu2,
 };
 
 MenuItem ftpmenu[] =
-{"FTP", 1, NULL, &submenu1};
+{"FTP", 1, NULL, submenu1};
 
 MenuItem menu2[] =
 {"1.Man", 5, manfunc, NULL,
@@ -359,34 +331,61 @@ MenuItem menu2[] =
  "-0.Quit", 2, donefunc, NULL
 };
 
+void init_submenus()
+{
+  submenu1=guiplugin->new_Menu(subm1, 13);
+  submenu2=guiplugin->new_Menu(subm2, 12);
+  submenu3=guiplugin->new_Menu(submnu2, 19);
+  submenu4=guiplugin->new_Menu(optmenu, 4);
+  menu[0].o=submenu1;
+  menu[1].o=submenu3;
+  menu[2].o=submenu4;
+  menu[3].o=submenu2;
+  ftpmenu[0].o=submenu1;
+}
+
 void   fqok();
 void   fqcan();
 
 
-extern void menupanel(int (*)(int, char *));
-extern int panexec2(int, char *);
-
 
 void   menu_func()
 {
   menupanel(panexec2);
 }
 
-Win    w1(300, 80, 200, 80, "Really, QUIT?", 5);
-KEY    qok(10, 35, 80, 25, "Yes", 2, fqok);
-KEY    qcan(110, 35, 80, 25, "Never", 1, fqcan);
+Win    *w1;
+KEY    *qok;
+KEY    *qcan;
 
 void   donefunc()
 {
-  w1.link(&qok);
-  qok.link(&qcan);
-  qcan.link(&qok);
-  qok.set_escapefunc(fqcan);
-  qcan.set_escapefunc(fqcan);
-  XMoveWindow(disp, w1.w, Mainl / 2 - 100, Mainh / 2 - 70);
-  w1.show();
-  qok.show();
-  qcan.show();
+  if(use_prompt & PROMPT_EXIT)
+  {
+    w1=guiplugin->new_Win(300, 80, 200, 80, "Really, QUIT?", 5);
+    qok=guiplugin->new_KEY(10, 35, 80, 25, "Yes", 2, fqok);
+    qcan=guiplugin->new_KEY(110, 35, 80, 25, "Never", 1, fqcan);
+    qok->set_iname("Q_YES");
+    qcan->set_iname("Q_NEVER");
+    w1->set_iname("QWIN");
+    w1->init(Main);
+    qok->init(w1->w);
+    qcan->init(w1->w);
+    w1->link(qok);
+    qok->link(qcan);
+    qcan->link(qok);
+    qok->set_escapefunc(fqcan);
+    qcan->set_escapefunc(fqcan);
+    XMoveWindow(disp, w1->w, Mainl / 2 - 100, Mainh / 2 - 70);
+    w1->show();
+    qok->show();
+    qcan->show();
+   }
+   else
+   {
+     clean_exit();
+     exit(0);
+   }
 }
 
 void   attrfunc()
@@ -396,19 +395,22 @@ void   attrfunc()
 
 void   fqok()
 {
-  qok.hide();
-  qcan.hide();
-  w1.hide();
+  qok->hide();
+  qcan->hide();
+  w1->hide();
   clean_exit();
   exit(0);
 }
 
 void   fqcan()
 {
-  qok.hide();
-  qcan.hide();
-  w1.hide();
-  XSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
+  qok->hide();
+  qcan->hide();
+  w1->hide();
+  delete qcan;
+  delete qok;
+  delete w1;
+  guiSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
 }
 
 Lister *lst1;
@@ -417,20 +419,24 @@ MenuBar *mn;
 MenuBar *mn2;
 Cmdline *cmdl;
 
-void   show_hidden_files()
-{
-  hide_hidden ^= 1;
-  panel->reread();
-  if (panel->lay == 0)
-    panel->panel2->reread();
-}
-
 void   p1brief()
 {
   lst1->brief = 1;
   lst1->reread();
 }
 
+void revfunc1()
+{
+  lst1->rev_order^=1;
+  lst1->reread();
+}
+
+void revfunc2()
+{
+  lst2->rev_order^=1;
+  lst2->reread();
+}
+
 void   p2brief()
 {
   lst2->brief = 1;
@@ -462,6 +468,14 @@ void   p1time()
 {
   lst1->sortbytime();
 }
+void   p1unsort()
+{
+  lst1->sortbyunsort();
+}
+void   p2unsort()
+{
+  lst2->sortbyunsort();
+}
 void   p1size()
 {
   lst1->sortbysize();
@@ -565,7 +579,7 @@ void   edit_ext()
 {
   char   name[120];
   strcpy(name, getenv("HOME"));
-  strcat(name, "/.xnc/.xnc.ext");
+  strcat(name, "/.xnc/xnc.ext");
   if (strcmp(editname, "internal") == 0)
     sendtoives(name, 1, 2);
   else
@@ -579,7 +593,7 @@ void   edit_menu()
 {
   char   name[120];
   strcpy(name, getenv("HOME"));
-  strcat(name, "/.xnc/.xnc.menu");
+  strcat(name, "/.xnc/xnc.menu");
   if (strcmp(editname, "internal") == 0)
     sendtoives(name, 1, 3);
   else
@@ -619,45 +633,59 @@ void   remntfunc()
   panel->remount();
 }
 
-extern void newtextfile(char *, Lister *, int);
 void   manfunc()
 {
   newtextfile("Man page", panel, 11);
 }
 
+void full_reconfig()
+{
+   mn->reconfigure(fsw1->l, 0, Mainl-fsw1->l, mn->menuh);
+   mn->substract_from_l(fsw1->l);
+   mn2->reconfigure(0, Mainh - mn2->menuh, Mainl, mn2->menuh);
+   cmdl->reconfigure(0, Mainh - 3 - mn2->menuh - cmdl->h, Mainl, cmdl->h);
+   fsw1->reconfigure(0,0, fsw1->l,fsw1->h);
+   fvis->reconfigure(fsw1->l,0,Mainl-fsw1->l,fvis->h);
+   bmark->reconfigure(0, mn->menuh, Mainl, Mainh - 23 - mn2->menuh - mn->menuh);
+   bmark->expose();
+   cmdl->expose();
+   mn->expose();
+   mn2->expose();
+   XFlush(disp);
+}
+
 void   XEVENT()
 {
 };
+
 int    evret;
 int    iii = 0;
-extern int focus_fl;
 int    resize_done2 = 0;
-extern int just_at_startup;
 int    Main_x = -1, Main_y = -1;
+
 int    XEVENT(XEvent * event)
 {
   Gui   *o;
   int    fiflg = 1;
   ev = *event;
   evret = 1;
+
   if (just_at_startup == 2 && ev.xany.window == Main)
     {
-      XSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
+      guiSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
       just_at_startup = 0;
+      full_reconfig();
       return 1;
     };
   if (ev.xany.window != Main)
     {
       if (ev.type == Expose)
         {
-/*    if(ev.xexpose.count==0)
-   { */
           o = findexp(ev.xany.window);
           if (o)
             o->click();
           else
             return 0;
-/*   } else return 0; */
         }
       else
         {
@@ -668,7 +696,7 @@ int    XEVENT(XEvent * event)
             {
               if (o == panel->panel2)
                 {
-                  XSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
+                  guiSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
                   return 0;
                 }
               else if (o != NULL)
@@ -694,25 +722,30 @@ int    XEVENT(XEvent * event)
               return XEVENT(&ev);
             }
           else
-            XSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
+            guiSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
         }
       else
-        XSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
+        guiSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
     }
   else if (ev.type == Expose && fiflg == 1 && focus_fl)
     {
-      XSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
+      guiSetInputFocus(disp, panel->w, RevertToParent, CurrentTime);
       fiflg = 0;
     }
   else if (ev.type == ClientMessage)
     {
-      if (ev.xclient.format == 32 && ev.xclient.data.l[0] == wmDeleteWindow)
-        donefunc();
+      xncdprintf(("Client message got\n"));
+      if(!iclient->check_event(&ev))
+	if (ev.xclient.format == 32 && ev.xclient.data.l[0] == wmDeleteWindow)
+	  donefunc();
     }
   else if (ev.type == MapNotify)
     main_show = 1;
   else if (ev.type == UnmapNotify)
+  {
     main_show = 0;
+    XIconifyWindow(disp, main_win, DefaultScreen(disp));
+  }
   else if (ev.type == ConfigureNotify)
     {                                //1
 
@@ -721,13 +754,15 @@ int    XEVENT(XEvent * event)
 
           Mainl = ev.xconfigure.width;
           Mainh = ev.xconfigure.height;
-          mn->reconfigure(0, 0, Mainl-20, 20);
-          mn2->reconfigure(0, Mainh - 20, Mainl, 20);
-          cmdl->reconfigure(0, Mainh - 43, Mainl, 20);
-          fsw1->reconfigure(Mainl-20,0,20,20);
+          mn->reconfigure(fsw1->l, 0, Mainl-fsw1->l, mn->menuh);
+          mn->substract_from_l(fsw1->l);
+          mn2->reconfigure(0, Mainh - mn2->menuh, Mainl, mn2->menuh);
+          cmdl->reconfigure(0, Mainh - 3 - mn2->menuh - cmdl->h, Mainl, cmdl->h);
+          fsw1->reconfigure(0,0, fsw1->l,fsw1->h);
+          fvis->reconfigure(fsw1->l,0,Mainl-fsw1->l,fvis->h);
           centerx = Mainl / 2;
           centery = Mainh / 2;
-          bmark->reconfigure(0, 20, Mainl, Mainh - 63);
+          bmark->reconfigure(0, mn->menuh, Mainl, Mainh - 23 - mn2->menuh - mn->menuh);
           if (term_sticky && resize_done2 == 0)
             {
               XResizeWindow(disp, main_win, Mainl, Mainh);
@@ -754,29 +789,31 @@ int    XEVENT(XEvent * event)
     };
   return evret;
 }
-extern "C" void tt_printf(char *f,...);
-extern char shdir[];
+
+
 void   xnc_sdir()
 {
-  tt_printf("cd '%s'\n", panel->curdir);
+  char tmpdir[L_MAXPATH];
+  tt_printf("cd %s\n", quote_path(tmpdir,panel->curdir));
   strcpy(shdir, panel->curdir);
 }
 
 void   sig_fault(int)
 {
+  signal(SIGSEGV, SIG_DFL);
   fprintf(stderr, "\n\n*******************************************************************************\n");
   fprintf(stderr, "OOPS! It seems that You found a bug in XNC!!!\n");
   fprintf(stderr, "If You can repeat this situation then send me a bug report\n");
-  fprintf(stderr, "to <leo@unix1.jinr.dubna.su> with subject  'XNC - bug report'\n");
+  fprintf(stderr, "to <leo@xnc.dubna.su> with subject  'XNC - bug report'\n");
   fprintf(stderr, "Body of mail:\n");
   fprintf(stderr, "   -What are You doing to produce this bug.\n"
-          "   -XNC configuration (~/.xnc/.xnc.ini) file.\n"
-          "   -Output of 'ldd xnc' command.\n"
-          "   -X Server configuration (resolution and color depth)\n");
+                  "   -XNC configuration (~/.xnc/xnc.ini) file.\n"
+                  "   -Output of 'ldd xnc' command.\n"
+                  "   -X Server configuration (resolution and color depth)\n");
   fprintf(stderr, "   -And Your reply mail address, for more information about situation if need\n");
   fprintf(stderr, "Do NOT include 'CORE' dump file in the following letter.\nThanks, and sorry for BUG\n");
   fprintf(stderr, "*******************************************************************************\n");
-  chdir("/core");
+  chdir(getenv("HOME"));
 }
 
 
@@ -787,12 +824,22 @@ void   xnc_main(int argc, char **argv)
   fprintf(stderr, "Initialisation:\n");
   margc = argc;
   margv = argv;
+  if(rs_plugin_name)
+    pluginman.load_look((char*)rs_plugin_name);
   InitXClient(argc, argv, 15, 70, 740, 455, ver);
   init_imagengine();
-  show_intro();
+  GuiLocale::init_locale();
+  iclient=new IVES_client(ives_retval);
+  if(is_show_intro() || is_new_version())
+          show_intro();
+  guiplugin->post_install();
+  xncdprintf(("MAIN WIN is 0x%X\n",Main));
   fprintf(stderr, "Connecting to IVE System.................");
   if (strcmp(viewname, "internal") != 0 && strcmp(editname, "internal") != 0)
+  {
     fprintf(stderr, "using externals\n");
+    no_ives=YES;
+  }
   else
     {
       strcpy(ivesrun, "ives ");
@@ -811,61 +858,71 @@ void   xnc_main(int argc, char **argv)
             else
               i++;
         }
-      if (ives_initshare())
-        ives_initshare();
+      if (iclient->Init()==0)
+	{
+	  fprintf(stderr,"failed (make it later)\n");
+	  no_ives=NO;
+	}
+      else
+      {
+	fprintf(stderr,"OK\n");
+	no_ives=NO;
+      }
     }
   compile_key_support();
-  compile_AFS_supports(".xnc.afs");
+  compile_AFS_supports("xnc.afs");
+  compile_FTP_supports("xnc.ftp");
   init_ftp_globals();
   create_dnd_cursors();
-  fprintf(stderr, "Loading Pixmaps.");
-  load_pixmaps();
-  bmark = new BookMark(35, Mainh - 63);
-  bmark->load_flags(7);
-  fprintf(stderr, "OK\n");
-  hide_intro();
+  bmark = guiplugin->new_BookMark(35, Mainh - 63);
+  bmark->set_iname("BOOKMARK");
+
 }
 
 void   xnc_exit();
 
 void   xnc_sig()
 {
-  signal(SIGUSR1, sigusr);
   signal(SIGSEGV, sig_fault);
   qv_signal();
 }
 
-extern AFS afstmp;
 void   xnc_gofunc()
 {
-  XMapWindow(disp, Main);
+  char str[512];
   mainuid = getuid();
   maingid = getgid();
   init_scroll();
+  init_xnc_alarm();
   init_qview();
-  mn = new MenuBar(0, 0, menu, 4);
-  mn2 = new MenuBar(0, Mainh - 20, menu2, 10);
-  emn = new MenuBar(0, viewh - 20, NULL, 4);
-  cmdl = new Cmdline(0, Mainh - 43, Mainl, 6);
-  fsw1= new Switcher(Mainl-20,0,20,20);
-  fvis= new FtpVisual(0,0,Mainl-20,20);
+  //  load_skins();
+  mn = guiplugin->new_MenuBar(20, 0, menu, 4);
   mn->substract_from_l(20);
+  mn->set_iname("MENU_UP");
   mn->init(Main);
+  fvis= guiplugin->new_FtpVisual(20,0,Mainl-20,mn->menuh);
+  init_submenus();
+  mn2 = guiplugin->new_MenuBar(0, Mainh - mn->menuh, menu2, 10);
+  emn = guiplugin->new_MenuBar(0, viewh - 20, NULL, 4);
+  fsw1= guiplugin->new_Switcher(0,0,20,mn->menuh);
+  mn2->set_iname("MENU_DN");
+  fvis->set_iname("FVISUAL");
+  fsw1->set_iname("MENU_SW");
+  mn->substract_from_l(fsw1->l);
   fvis->init(Main);
   mn2->init(Main);
+  cmdl = guiplugin->new_Cmdline(0, Mainh - 23 - mn2->menuh, Mainl, 6);
+  cmdl->set_iname("CMDLINE");
   bmark->init(Main);
   fsw1->init(Main);
   fsw1->add_gui(mn);
 #ifndef DISABLE_FTP
   fsw1->add_gui(fvis);
 #endif
-  bmark->create_listers(&lst1, &lst2);
+  bmark->create_listers(&lst1, &lst2, 0, mn->menuh, 23+mn2->menuh);
   lst1->init(Main);
   lst2->init(Main);
   cmdl->init(Main);
-  w1.init(Main);
-  qok.init(w1.w);
-  qcan.init(w1.w);
   lst1->setviewer(viewload, viewonlyload);
   lst2->setviewer(viewload, viewonlyload);
   lst1->seteditor(editload);
@@ -873,6 +930,26 @@ void   xnc_gofunc()
   fprintf(stderr, "Last version :  %s\n", created);
   fprintf(stderr, "Code compiled : %s\n", compiled);
   load_cfg(lst1, lst2);
+  sprintf(str,"%s/.xnc/xnc.history",getenv("HOME"));
+  fprintf(stderr,"Loading history........");
+  init_history();
+  hist_loadall(str,YES);
+
+  fprintf(stderr, "Loading pixmaps.");
+  load_pixmaps();
+//  main_pixmap=get_rootwindow_pixmap();
+  bmark->load_flags(7);
+  if(is_back_load())
+     fprintf(stderr, "later (back load)\n");
+  else
+     fprintf(stderr, "OK\n");
+  unset_back_load();
+  magic_init(magic_file_location, 1);
+  hide_intro();
+  fprintf(stderr, "Starting %s Build%s.....\n", ver, build_chr);
+
+  map_vt_windows(main_pixmap);
+  XMapWindow(disp, Main);
   bmark->rebuild_listers();
   lst1->show();
   lst2->show();
@@ -884,14 +961,16 @@ void   xnc_gofunc()
   lst2->setpanel(lst1);
   lst1->setcmdl(cmdl);
   lst2->setcmdl(cmdl);
-  lst1->setsubmenu(&submenu1);
-  lst2->setsubmenu(&submenu2);
+  lst1->setsubmenu(submenu1);
+  lst2->setsubmenu(submenu2);
   cmdl->setpath(panel->curdir);
   bmark->show();
   afstmp.set_dir_pointer(NULL, 1024);
   wmDeleteWindow = XInternAtom(disp, "WM_DELETE_WINDOW", False);
   XSetWMProtocols(disp, Main, &wmDeleteWindow, 1);
-  fprintf(stderr, "Copyright (c) 1995-98 Leonid V. KHramov aka Leo <leo@unix1.jinr.dubna.su>\n");
+//  full_reconfig();
+  fprintf(stderr, "Copyright (c) 1995-2000 Leonid V. KHramov aka Leo <leo@xnc.dubna.su>\n");
+  au_out=0;  //Switch off SUP compilation output.
 }
 
 void   xnc_animate()
@@ -932,18 +1011,35 @@ void   xnc_exit()
         {
           x_free_pixmaps();
         }
-      str = new char[2048];
+      str = new char[L_MAXPATH];
       sprintf(str, "rm -rf %s/.%d.*", syspath, getpid());
       psystem(str);
       sprintf(str, "rm -rf %s/AFS/afs.%d.*", syspath, getpid());
       psystem(str);
-      delete str;
       deinit_scroll();
-      ives_deinit();
+      if((option_bits & IVES_EXIT_TOO) && iclient && iclient->Init())
+          sendtoives("shutdown", 6); //Say IVES bye, bye :)
       deinit_keysupport();
       deinit_AFS_supports();
+      ftpcfg_deinit_hosts();
+      sprintf(str,"%s/.xnc/xnc.history",getenv("HOME"));
+      hist_saveall(str);
+      delete str;
       fprintf(stderr, "OK\n");
+      fprintf(stderr, "------------------------------------------------------------------------------\n");
+      fprintf(stderr, "Notice:\n\tIf You like X Northern Captain and will use it,\n");
+      fprintf(stderr,"\tthen send me e-mail to <leo@xnc.dubna.su> with names of\n");
+      fprintf(stderr,"\tcity and country where you are using it. It's for my collection.\n");
+      fprintf(stderr,"\tIf You do it, i'll be happy....\n");
+      fprintf(stderr,"\t\t\tThanks,\n\t\t\tLeonid V. Khramov aka Leo <leo@xnc.dubna.su>\n");
+      fprintf(stderr,"\nPS: If you have any questions, comments about xnc or you want\n"
+	             "to know latest news then join to xnc mailing list <xnc@xnc.dubna.su>\n"
+                     "Just mail a letter with 'SUBSCRIBE xnc' in the body of mail to\n"
+	             "<majordomo@xnc.dubna.su> and you are inside.\n");
+      fprintf(stderr, "------------------------------------------------------------------------------\n");
+      fprintf(stderr, "Thank you. You have run X Northern Captain %d times!\n", xnc_starts);
       DeinitXClient();
     }
 }
 void   (*xnc_kill) () = xnc_exit;
+void   (*xnc_run_once) () = 0;
