@@ -1,6 +1,6 @@
 /****************************************************************************
-*  Copyright (C) 1996-97 by Leo Khramov
-*  email:     leo@pop.convey.ru
+*  Copyright (C) 1996-99 by Leo Khramov
+*  email:     leo@xnc.dubna.su
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -12,31 +12,92 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-#include "pager.h"
+#include "xh.h"
+#include "../pager.h"
 #include "../image/imload.h"
 #include "../scroll.h"
 #include "../gui.h"
 #include "../au/x_actions.h"
 #include "../au/key.h"
+#include "../tartest.h"
+#include "../geomfuncs.h"
+#include "../baseguiplugin.h"
 
 char home_files_dir[1024];
 
 #ifdef XNC_DIR
 char *xnc_dir=XNC_DIR;
 #else
-char *xnc_dir="/usr/xnc/data";
+char *xnc_dir="/usr/local/lib/xnc/data";
 #endif
 
+
+char ininame[1024];
+
+static void print_error(char* err)
+{
+    fprintf(stderr, err);
+}
+
+extern int sfiles_chr_size;
+extern char sfiles_chr[];
+
+int oldtar=1;
+char tarvers[80]="nonGNU";
+
+extern int detect_tar_output(char*);
+
+void extract_setup_files(char *home)
+{
+        char tmp[2048];
+        char tmp2[2048];
+        int fp;
+        sprintf(tmp,"%s/.xnc",home);
+        mkdir(tmp,0700);
+        sprintf(tmp,"%s/.xnc/.setup",home);
+        sprintf(tmp2, "rm -rf %s", tmp);
+        system(tmp2);
+        if(mkdir(tmp,0700)==-1)
+                return;
+        chdir(tmp);
+        fp=open("files.tar",O_WRONLY | O_CREAT | O_TRUNC, 0600);
+        if(fp==-1)
+                {
+                        fprintf(stderr,"********Setup Fatal Error: Extract files : %s\n",strerror(errno));
+                        return;
+                }
+        write(fp,sfiles_chr,sfiles_chr_size);
+        close(fp);
+        system("tar -xf files.tar");
+        unlink("files.tar");
+}
+
+int create_file(char *path, char *fname, char *buf, int siz)
+{
+        char str[2048];
+        int fp;
+        sprintf(str,"%s/%s",path,fname);
+        fp=open(str,O_WRONLY | O_CREAT,0600);
+        if(fp==-1)
+                return 0;
+        write(fp,buf,siz);
+        close(fp);
+        return 1;
+}
+
+
 char current_dir[512];
 char *rel_dir="./data";
 
 void check_source_dirs()
 {
+ char setup_dir[2048];
  getcwd(current_dir,512);
  strcpy(home_files_dir,getenv("HOME"));
+ sprintf(setup_dir,"%s/.xnc/.setup/data",home_files_dir);
  strcat(home_files_dir,"/.xnc");
  if(chdir(rel_dir)==-1)
-  if(chdir(xnc_dir)==-1)
+  if(chdir(setup_dir)==-1)
   {
    fprintf(stderr,"\n****************************************************************\n"
         "Global ERROR: Can't find XNC system configuration files in '%s' or '%s'\n"
@@ -75,8 +136,10 @@ char chgeom[30]="750x550+10+5";
 char chedit[100]="internal";
 char chview[100]="internal";
 char chfont[100]="";
-char rustbl[256];
-char wrustbl[256];
+unsigned char rustbl[256];
+unsigned char wrustbl[256];
+unsigned char wintbl[256];
+unsigned char dostbl[256];
 extern int done;
 int not_saved=1;
 int showed=0;
@@ -151,7 +214,7 @@ void init_key_array()
  char *b;
  ActionKey* ac;
  compile_internal_key_support();
- parse_file_in_replace_mode("/.xnc.keys");
+ parse_file_in_replace_mode("/xnc.keys");
  while(j<AEmpty)
  {
   b=action_name_by_code(j);
@@ -188,7 +251,8 @@ int eventkey_to_action()
  ActionKey* ac=action_by_name(kn[n]);
  if(ac==NULL) {XBell(disp,0);return 0;};
  ks=XKeycodeToKeysym(disp,ev.xkey.keycode,0);
- if(ks==XK_Alt_L || ks==XK_Alt_R || ks==XK_Control_L || ks==XK_Control_R || ks==XK_Shift_L || ks==XK_Shift_R) return 0;
+ if(ks==XK_Alt_L || ks==XK_Alt_R || ks==XK_Control_L || ks==XK_Control_R || ks==XK_Shift_L || ks==XK_Shift_R) 
+        return 0;
  for(i=0;i<keynum;i++)
   if(ac->mods[i]==0 && ac->keys[i]==0) break;
  ac->keys[i]=ev.xkey.keycode;
@@ -198,6 +262,25 @@ int eventkey_to_action()
  return 1;
 }
 
+void clear_actionkey()
+{
+ KeySym ks;
+ int n=kpanel.base+kpanel.cur,i;
+ ActionKey* ac=action_by_name(kn[n]);
+ if(ac==NULL) {XBell(disp,0);return;};
+ for(i=0;i<3;i++)
+  if(ac->mods[i]==0 && ac->keys[i]==0)
+      break;
+ i--;
+ if(i<=0)
+         return;
+ ac->keys[i]=0;
+ ac->mods[i]=0;
+ reconstruct_key_string(n);
+ kpanel.expose();
+ XFlush(disp);
+}
+
 void fmeskok()
 {
  gen_ini();
@@ -251,20 +334,20 @@ MenuItem micols[]={"Background",4,colfunc,NULL,
                                  };
 
 int transcol[]={7,0,13,15,15,4,3,5,11,12,6,2,10,9};
-int  startcol[14][3]={{158,160,168},
+int  startcol[14][3]={{0xb7,0xb0,0xae},
                                        {0x00,0x00,0x00},
                                        {0xff,0xff,0xff},
                                        {0xff,0x00,0x00},
                                        {0x00,0xff,0x00},
                                        {0x00,0x00,0xff},
                                        {0xff,0xff,0x00},
-                                       {134,16,182},
-                                       {142,229,238},
-                                       {229,229,229},
-                                       {238,18,137},
-                                       {0x39,0xff,0x11},
-                                       {0xff,0xcf,0xf9},
-                                       {0xfb,0xc9,0x8e}};
+                                       {0x86,0x10,0xb6},
+                                       {0x8e,0xe5,0xee},
+                                       {0xff,0xff,0xff},
+                                       {0x13,0x12,0xf8},
+                                       {0x00,0xff,0x34},
+                                       {0x00,0xff,0xf2},
+                                       {0xfb,0x50,0x56}};
 ////////////////////////////////////////////////////////////////////////////////////////////////
 class KeyWin:public Win
 {
@@ -366,7 +449,7 @@ void KeyWin::click()
 class PicShower:public Gui
 {
   public:
-   int x,y,l,h,shown,max,ptn;
+   int shown,max,ptn;
    unsigned long pt[256];
    XImage *im;
    PICINFO pic;
@@ -437,7 +520,7 @@ void PicShower::expose()
 class ColShower:public Gui
 {
   public:
-   int x,y,l,h,shown;
+   int shown;
    XColor col;
    ColShower(int ix,int iy,int il,int ih):Gui()
     {x=ix;y=iy;l=il;h=ih;shown=0;col.pixel=0;};
@@ -493,7 +576,7 @@ void ColShower::expose()
 class FontShower:public Gui
 {
   public:
-   int x,y,l,h,shown;
+   int shown;
    XFontStruct *font;
    FontShower(int ix,int iy,int il,int ih):Gui()
     {x=ix;y=iy;l=il;h=ih;font=NULL;shown=0;};
@@ -544,8 +627,9 @@ void FontShower::expose()
  if(font)
  {
   ty=h/2-(font->max_bounds.ascent+font->max_bounds.descent)/2;
-  tx=XTextWidth(font,"ABCDEFsdfghjk1234567890{}",25)/2;
-  XDrawString(disp,w,gcw,l/2-tx,ty+font->max_bounds.ascent,"ABCDEFsdfghjk1234567890{}",25);
+  tx=XTextWidth(font,"ABCDEFsdfghjk1234567890{}",30)/2;
+  XDrawString(disp,w,gcw,l/2-tx,ty+font->max_bounds.ascent,
+              "ABCDEFsdfghjk1234567890{}",30);
   }
 }
 
@@ -574,12 +658,12 @@ void whats_new()
 
 void setcol();
 char **nfonts;                                 
-int xnclay=0,lastfont;      
-char chfonts[5][100]={"-*-helvetica-bold-o-normal-*-12-*-*-*-*-*-*-*",
-                                           "-*-helvetica-bold-r-*-*-12-*-*-*-*-*-*-*",
-                                           "-*-fixed-bold-r-*-*-14-*-*-*-*-*-*-*",
-                                           "-*-times-medium-r-*-*-14-*-*-*-*-*-*-*",
-                                           "-*-fixed-medium-r-*-*-10-*-*-*-*-*-*-*"
+int xnclay=2,lastfont;      
+char chfonts[5][100]={"-*-helvetica-*-r-*-*-12-*-*-*-*-*-*-*",
+   "-*-helvetica-*-r-*-*-14-*-*-*-*-*-*-*",
+   "-*-fixed-*-r-*-*-14-*-*-*-*-*-*-*",
+   "-*-fixed-*-r-*-*-14-*-*-*-*-*-*-*",
+   "-*-fixed-*-r-*-*-10-*-*-*-*-*-*-*"
 };
 Sw_panel slay(20,220,200,"XNC Layout",milay,3);
 Sw_panel sfont(10,250,160,"Fonts",mifont,5);
@@ -603,6 +687,30 @@ ScrollBar sbgreen(250,70,260,NULL);
 ScrollBar sbblue(310,70,260,NULL);
 int curcol=2;
 
+void set_start_colors()
+{
+   int r,g,b,rr,gg,bb;
+   for(int i=0;i<14;i++)
+     {
+	r=startcol[i][0];
+	g=startcol[i][1];
+	b=startcol[i][2];
+	if(transcol[i]==transcol[0])
+	  {
+	     clipl.pic.pal[3]=r*60/100;
+	     clipl.pic.pal[4]=g*60/100;
+	     clipl.pic.pal[5]=b*60/100;
+	     rr=r*130/100;if(rr>255)  rr=255;
+	     gg=g*130/100;if(gg>255)  gg=255;
+	     bb=b*130/100;if(bb>255)  bb=255;
+	     clipl.pic.pal[24]=rr;
+	     clipl.pic.pal[25]=gg;
+	     clipl.pic.pal[26]=bb;
+	  }
+	clipl.setcol(transcol[i], r, g, b);
+     }
+}
+
 void rscring(Gui* o)
 {
  int r,g,b;
@@ -925,25 +1033,26 @@ MenuItem miup[]={"Always",3,NULL,NULL,
 Pager p1(0,0,530,425,5);
 Separator csep(10,185,510,&p1);
 Separator csep2(10,165,510,&p1);
-Separator csep3(10,225,510,&p1);
-Separator csep4(10,125,510,&p1);
+Separator csep3(10,170,510,&p1);
+Separator csep4(10,105,510,&p1);
 
 Text tkey(10,45,"Hot Keys to XNC Actions mapping:",5);
 Panel kpanel(10,75,500,300,karr,0,1,NULL);
-KEY kkey1(25,385,130,25,"Key1",4,keyfunc1);
-KEY kkey2(190,385,130,25,"Key2",4,keyfunc2);
-KEY kkey3(350,385,130,25,"Key3",4,keyfunc3);
-Text tterm(10,45,"Terminal:",5);
+KEY kkey1(25,385,100,25,"Key1",4,keyfunc1);
+KEY kkey2(140,385,100,25,"Key2",4,keyfunc2);
+KEY kkey3(250,385,100,25,"Key3",4,keyfunc3);
+KEY kkey4(390,385,100,25,"Clear",2,clear_actionkey);
+Text tterm(10,45,"IVES->XNC:",5);
 Switch swsticky(20,65,180,"Sticky terminal",1);
 Switch swraise(20,95,240,"Raise terminal on exec",1);
-Switch swfocus(20,138,240,"Return Focus from IVES",1);
-Text tbookmark(10,185,"Bookmark Options:",5);
-Switch swbook(20,200,200,"Enable Bookmark",1);
+Switch swfocus(20,65,240,"Return Focus from IVES",1);
+Text tbookmark(10,125,"Bookmark Options:",5);
+Switch swbook(20,145,200,"Enable Bookmark",1);
 Switch swanim(250,200,270,"Allow Bookmark animation",1);
-Text ticons(10,250,"Icons:",5);
+Text ticons(10,190,"AFS Options:",5);
 Switch swdiricon(20,265,290,"Show icons with directory names",1);
 Switch swfileicon(20,295,230,"Show icons with files",1);
-Sw_panel supdate(310,240,200,"Update archieve on exit",miup,3);
+Sw_panel supdate(60,220,200,"Update archieve on exit",miup,3);
 char *pn[5]={"Common","Colors","Fonts","Keys","Other"};
 char *traise="yes";
 char *tsticky="yes";
@@ -976,15 +1085,18 @@ char *chncols[]={"keys.background",
                                   "list.execution",
                                   "list.link",
                                   "afs.color"};
-void gen_inis(char *name1,char* name2)
+void gen_inis(char *name1,char* name2, int make_full_path=1)
 {
- char n[255];
+ char n[1024]="";
  char tmp[100];
  char *clay[]={"vertical","horizontal","page"};
  FILE* fp;
  int i;
- strcpy(n,getenv("HOME"));
- strcat(n,"/.xnc");
+ if(make_full_path)
+ {
+   strcpy(n,getenv("HOME"));
+   strcat(n,"/.xnc");
+ }
  strcat(n,name1);
  fp=fopen(n,"w");
  if(fp!=NULL)
@@ -1021,28 +1133,29 @@ void gen_inis(char *name1,char* name2)
   fprintf(fp,"xnc.geometry:   %s\n",chgeom);
   fprintf(fp,"xnc.viewer.geometry:   %s\n",chgeom);
   fprintf(fp,"xnc.panels.layout:     %s\n",clay[xnclay]);
-  fprintf(fp,"xnc.terminal.allow_raising:     %s\n",traise);
-  fprintf(fp,"xnc.terminal.stick_both:     %s\n",tsticky);
-  fprintf(fp,"xnc.bookmark.allow_animation:     %s\n",book_anim);
   fprintf(fp,"xnc.bookmark.show_and_use:     %s\n",book_show);
-  fprintf(fp,"xnc.icons.dir:     %s\n",dir_icon);
-  fprintf(fp,"xnc.icons.files:     %s\n",file_icon);
   fprintf(fp,"xnc.afs.update:     %s\n",update_chr);
   fprintf(fp,"leoprogs.focus.return:     %s\n",ret_foc);
+  if(name2[0]=='I')
+          fprintf(fp,"leoprogs.text.shadow:   yes\n");
   fprintf(fp,"#File generated by X Northern Captain Setup.....\n");
   fclose(fp);
  }
 }
 void gen_ini()
 {
- char tmp2[180]="cp -f ../pixs/* ";
- char tmp1[180]="cp -f ru.* ";
- char tmp3[180]="chmod a+w ";
+ char tmp2[1180]="cp -f ../pixs/* ";
+ char tmp1[1180]="cp -f ru.* ";
+ char tmp3[1180]="chmod a+w ";
+ char tmp4[1180];
+ int oldtar;
  not_saved=0;
+ sprintf(tmp4,"%s/.xnc/.setup",getenv("HOME"));
+ oldtar=detect_tar_output(tmp4);
  system("mkdir $HOME/.xnc >/dev/null 2>/dev/null");
- gen_key_file("/.xnc.keys");
- gen_inis("/.xnc.ini","X Northern Captain.......");                                
- gen_inis("/.ives.ini","IVES.......");
+ gen_key_file("/xnc.keys");
+ gen_inis(ininame,"X Northern Captain.......",0);
+ gen_inis("/ives.ini","IVES.......");
  mkdir(chsys,0777);
  strcat(tmp2,chsys);
  strcat(tmp1,chsys);
@@ -1050,57 +1163,93 @@ void gen_ini()
  system(tmp3);
  system(tmp2);
  system(tmp1);
- system("sh ./setup.script");
+        switch(oldtar)
+        {
+                case GNUTAR_1_11:
+                        fprintf(stderr,"Using GNU old style tar output for AFS\n");
+                        system("./setup.script ./.xnc.afs");
+                        break;
+                case GNUTAR_1_12:
+                        fprintf(stderr,"Using new/ISO GNU style tar output for AFS\n");
+                        system("./setup.script ./xnc.afs.tar112");
+                        break;
+                case OPENTAR_1_11:
+                        fprintf(stderr,"Using GNU OpenBSD style tar output for AFS\n");
+                        system("./setup.script ./xnc.afs.openbsdtar");
+                        break;
+                case AIXTAR_1:
+                        fprintf(stderr,"Using AIX style tar output for AFS\n");
+                        system("./setup.script ./xnc.afs.aixtar");
+                        break;
+                default:
+                        fprintf(stderr, "Detected unknown [%d] tar output! Use default...\n",oldtar);
+                        fprintf(stderr, "**If You will have problems reading TAR archives then\n");
+                        fprintf(stderr, "**mail code printed above to <leo@xnc.dubna.su>\n");
+                        system("./setup.script ./.xnc.afs");
+                        break;
+        }
  strcat(chsys,"/AFS");
- mkdir(chsys,0777);
+ mkdir(chsys,0755);
+ strcpy(strrchr(chsys, '/'), "/FTP");
+ mkdir(chsys,0700);
+ system("./postsetup.script");
  fqok();
 }
 
 
 char *colchr;
+char colchr1[100];
+char colchr2[100];
+char colchr3[100];
+char colchr4[100];
+char colchr5[100];
+char colchr6[100];
+char colchr7[100];
+char colchr8[100];
+char colchr9[100];
+char colchr10[100];
+char colchr11[100];
+char colchr12[100];
+char colchr13[100];
+char colchr14[100];
 X_PAR xpcols[]=
 {
-  "leoprogs.keys.background","LeoProgs.Keys.Background",&colchr,
-  "leoprogs.syscolor1","LeoProgs.SysColor1",&colchr,
-  "leoprogs.syscolor2","LeoProgs.SysColor2",&colchr,
-  "leoprogs.syscolor3","LeoProgs.SysColor3",&colchr,
-  "leoprogs.syscolor4","LeoProgs.SysColor4",&colchr,
-  "leoprogs.syscolor5","LeoProgs.SysColor5",&colchr,
-  "leoprogs.syscolor6","LeoProgs.SysColor6",&colchr,
-  "leoprogs.selectedcolor","LeoProgs.SelectedColor",&colchr,
-  "leoprogs.list.extensions","LeoProgs.List.Extensions",&colchr,
-  "leoprogs.list.normfile","LeoProgs.List.Normfile",&colchr,
-  "leoprogs.list.directory","LeoProgs.List.Directory",&colchr,
-  "leoprogs.list.execution","LeoProgs.List.Execution",&colchr,
-  "leoprogs.list.link","LeoProgs.List.Link",&colchr,
-  "leoprogs.afs.color","LeoProgs.AFS.Color",&colchr
+  "leoprogs.keys.background","LeoProgs.Keys.Background",colchr1,
+  "leoprogs.syscolor1","LeoProgs.SysColor1",colchr2,
+  "leoprogs.syscolor2","LeoProgs.SysColor2",colchr3,
+  "leoprogs.syscolor3","LeoProgs.SysColor3",colchr4,
+  "leoprogs.syscolor4","LeoProgs.SysColor4",colchr5,
+  "leoprogs.syscolor5","LeoProgs.SysColor5",colchr6,
+  "leoprogs.syscolor6","LeoProgs.SysColor6",colchr7,
+  "leoprogs.selectedcolor","LeoProgs.SelectedColor",colchr8,
+  "leoprogs.list.extensions","LeoProgs.List.Extensions",colchr9,
+  "leoprogs.list.normfile","LeoProgs.List.Normfile",colchr10,
+  "leoprogs.list.directory","LeoProgs.List.Directory",colchr11,
+  "leoprogs.list.execution","LeoProgs.List.Execution",colchr12,
+  "leoprogs.list.link","LeoProgs.List.Link",colchr13,
+  "leoprogs.afs.color","LeoProgs.AFS.Color",colchr14
 };
 
 int xpcoln=sizeof(xpcols)/sizeof(X_PAR);
 
 X_PAR xpfont[]=
 {
-  "leoprogs.font","LeoProgs.Font",&colchr,
-  "leoprogs.list.font","LeoProgs.List.Font",&colchr,
-  "leoprogs.font.fixed","LeoProgs.Font.Fixed",&colchr,
-  "leoprogs.viewer.font","LeoProgs.Viewer.Font",&colchr,
-  "leoprogs.font.minifixed","LeoProgs.Font.MiniFixed",&colchr
+  "leoprogs.font","LeoProgs.Font",colchr,
+  "leoprogs.list.font","LeoProgs.List.Font",colchr,
+  "leoprogs.font.fixed","LeoProgs.Font.Fixed",colchr,
+  "leoprogs.viewer.font","LeoProgs.Viewer.Font",colchr,
+  "leoprogs.font.minifixed","LeoProgs.Font.MiniFixed",colchr
  };
 int xpfontn=sizeof(xpfont)/sizeof(X_PAR);
 X_PAR xpcom[]=
 {
-  "xnc.sysfiles.path","Xnc.SysFiles.Path",&colchr,
-  "xnc.editor.name","Xnc.Editor.Name",&colchr,
-  "xnc.viewer.name","Xnc.Viewer.Name",&colchr,
-  "xnc.geometry","Xnc.Geometry",&colchr,
-  "xnc.terminal.allow_raising","Xnc.Terminal.Allow_Raising",&traise,
-  "xnc.terminal.stick_both","Xnc.Terminal.Stick_Both",&tsticky,
-  "leoprogs.focus.return","LeoProgs.Focus.Return",&ret_foc,
-  "xnc.bookmark.allow_animation","Xnc.BookMark.Allow_Animation",&book_anim,
-  "xnc.bookmark.show_and_use","Xnc.BookMark.Show_and_Use",&book_show,
-  "xnc.icons.dir","Xnc.Icons.Dir",&dir_icon,
-  "xnc.icons.files","Xnc.Icons.Files",&file_icon,
-  "xnc.afs.update","Xnc.AFS.Update",&update_chr
+  "xnc.sysfiles.path","Xnc.SysFiles.Path",colchr,
+  "xnc.editor.name","Xnc.Editor.Name",colchr,
+  "xnc.viewer.name","Xnc.Viewer.Name",colchr,
+  "xnc.geometry","Xnc.Geometry",colchr,
+  "leoprogs.focus.return","LeoProgs.Focus.Return",ret_foc,
+  "xnc.bookmark.show_and_use","Xnc.BookMark.Show_and_Use",book_show,
+  "xnc.afs.update","Xnc.AFS.Update",update_chr
  };
 int xpcomn=sizeof(xpcom)/sizeof(X_PAR);
 char chra[5]="yes";
@@ -1111,7 +1260,7 @@ char chbo[5]="yes";
 char chdicon[5]="yes";
 char chficon[5]="yes";
 char chupd[10]="never";
-char *chcom[]={chsys,chedit,chview,chgeom,chra,chst,chre,chan,chbo,chdicon,chficon,chupd};
+char *chcom[]={chsys,chedit,chview,chgeom,chre,chbo,chupd};
 void load(char *rfile)
 {
  char *rmt;
@@ -1123,7 +1272,7 @@ void load(char *rfile)
   for(i=0;i<xpcoln;i++)
    if(XrmGetResource(rdb,xpcols[i].name,xpcols[i].cname,&rmt,&rmv))
    {
-    *xpcols[i].pstr=rmv.addr;
+    strcpy(xpcols[i].pstr, rmv.addr);
      XParseColor(disp,defcmp,rmv.addr,&xcol);
      startcol[i][0]=r=xcol.red/256;
      startcol[i][1]=g=xcol.green/256;
@@ -1175,13 +1324,8 @@ void load(char *rfile)
  file_icon=chficon;
  update_chr=chupd;
  supdate.excl();
- if(strcmp(tsticky,"yes")==0) swsticky.sw=1;else swsticky.sw=0;
- if(strcmp(traise,"yes")==0) swraise.sw=1;else swraise.sw=0;
  if(strcmp(ret_foc,"yes")==0) swfocus.sw=1;else swfocus.sw=0;
  if(strcmp(book_show,"no")==0) swbook.sw=0;else swbook.sw=1;
- if(strcmp(book_anim,"no")==0) swanim.sw=0;else swanim.sw=1;
- if(strcmp(dir_icon,"no")==0) swdiricon.sw=0;else swdiricon.sw=1;
- if(strcmp(file_icon,"no")==0) swfileicon.sw=0;else swfileicon.sw=1;
  if(strcmp(update_chr,"always")==0) supdate.set(0,1); else
   if(strcmp(update_chr,"prompt")==0) supdate.set(2,1); else supdate.set(1,1);
 }          
@@ -1191,11 +1335,15 @@ void main(int argc,char** argv)
 {
  char *name="X Northern Captain Setup";
  int i,nf,fp11,lfl;
+ mlook=LOOKFOUR;
  fprintf(stderr,"Initialisation:\n");
+ extract_setup_files(getenv("HOME"));
  sprintf(chsys,"%s/.xnc/xnctmp",getenv("HOME"));
  margc=argc;margv=argv; 
  check_source_dirs();
+ system("./postsetup.script");
  InitXClient(argc,argv,30,70,540,475,name);
+ init_basegui_plugin();
 #if 0
  pid=fork();
  if(pid==-1)
@@ -1213,6 +1361,9 @@ void main(int argc,char** argv)
  {
  init_imagengine();
  init_scroll();
+
+ GuiLocale::init_locale();
+    
  sbred.setpages(25);
  sbgreen.setpages(25);
  sbblue.setpages(25);
@@ -1243,6 +1394,7 @@ void main(int argc,char** argv)
  kkey1.init(p1.w);
  kkey2.init(p1.w);
  kkey3.init(p1.w);
+ kkey4.init(p1.w);
  tsys.init(p1.w);
  tgeom.init(p1.w);
  tedit.init(p1.w);
@@ -1288,8 +1440,8 @@ void main(int argc,char** argv)
  gifl.load("../xncvert.gif");
  gifl.load("../xnchor.gif");
  gifl.load("../xncpage.gif");
- gifl.setpage(0);
- slay.set(0,1);
+ gifl.setpage(2);
+ slay.set(2,1);
  sfont.set(0,1);
  scols.set(2,1);
  supdate.set(2,1);
@@ -1308,17 +1460,26 @@ void main(int argc,char** argv)
   swfileicon.sw=1;
  };
  lfl=1;
+
+ set_start_colors();
+
  if(argc>1)
    for(i=1;i<argc;i++)
-    if(strcmp(argv[i],"-l")==0) {load(argv[i+1]);lfl=0;};
+    if(strcmp(argv[i],"-l")==0) 
+    {
+      load(argv[i+1]);
+      lfl=0;
+      strncpy(ininame,argv[i+1],1024);
+    };
  if(lfl)
  {
-  sprintf(tmpstr,"%s/.xnc/.xnc.ini",getenv("HOME"));
+  sprintf(tmpstr,"%s/.xnc/xnc.ini",getenv("HOME"));
   if((fp11=open(tmpstr,O_RDONLY))!=-1)
   {
    close(fp11);
    load(tmpstr);
   }
+  strcpy(ininame,tmpstr);
  }
  strcpy(chfont,chfonts[0]);
  isys.setbuf(chsys,255);
@@ -1382,22 +1543,17 @@ void main(int argc,char** argv)
  p1.addobj(&tfont);
  p1.addobj(&fsfont);
  p1.setpage(3);
-  p1.pagemaxobj(5);
+  p1.pagemaxobj(6);
  p1.addobj(&tkey);
  p1.addobj(&kpanel);
  p1.addobj(&kkey1);
  p1.addobj(&kkey2);
  p1.addobj(&kkey3);
+ p1.addobj(&kkey4);
  p1.setpage(4);
   p1.pagemaxobj(14);
- p1.addobj(&swsticky);
- p1.addobj(&swraise);
  p1.addobj(&swfocus);
  p1.addobj(&swbook);
- p1.addobj(&swanim);
- p1.addobj(&swdiricon);
- p1.addobj(&swfileicon);
- p1.addobj(&csep2);
  p1.addobj(&csep3);
  p1.addobj(&csep4);
  p1.addobj(&ticons);
@@ -1423,10 +1579,11 @@ void main(int argc,char** argv)
  whats_new();
  while(!done)  XEVENT();
  XFreeFontNames(nfonts);
- for(i=0;i<kmax;i++) delete karr[i];
+ for(i=0;i<kmax;i++)
+         delete karr[i];
  deinit_scroll();
  fprintf(stderr,"Exiting from Setup....");
- if(vrw) {vrw->hide();delete vrw;};
+ if(vrw) {vrw->hide();};
  chdir(current_dir);
  fprintf(stderr,"OK\n");
  DeinitXClient();
